from rdflib import URIRef

# WARNING. This is a Generated File. Please do not edit.
# Please refer to the README at java/src/main/java/com/ncc/aif/ont2javagen for more information
# Last generated on: 08/24/2020 11:09:20
NAMESPACE = 'https://raw.githubusercontent.com/NextCenturyCorporation/AIDA-Interchange-Format/master/java/src/main/resources/com/ncc/aif/ontologies/LDCOntology#'

# Classes
ArtifactExistence_DamageDestroy = URIRef(NAMESPACE + 'ArtifactExistence.DamageDestroy')
ArtifactExistence_DamageDestroy_Damage = URIRef(NAMESPACE + 'ArtifactExistence.DamageDestroy.Damage')
ArtifactExistence_DamageDestroy_Destroy = URIRef(NAMESPACE + 'ArtifactExistence.DamageDestroy.Destroy')
BAL = URIRef(NAMESPACE + 'BAL')
BAL_BallotSlate_BallotSlate = URIRef(NAMESPACE + 'BAL.BallotSlate.BallotSlate')
BAL_PaperBallot_PaperBallot = URIRef(NAMESPACE + 'BAL.PaperBallot.PaperBallot')
COM = URIRef(NAMESPACE + 'COM')
COM_Document = URIRef(NAMESPACE + 'COM.Document')
COM_Document_Map = URIRef(NAMESPACE + 'COM.Document.Map')
COM_Document_PersonalIdentification = URIRef(NAMESPACE + 'COM.Document.PersonalIdentification')
COM_Equipment = URIRef(NAMESPACE + 'COM.Equipment')
COM_Equipment_HumanitarianAid = URIRef(NAMESPACE + 'COM.Equipment.HumanitarianAid')
COM_Equipment_MedicalEquipment = URIRef(NAMESPACE + 'COM.Equipment.MedicalEquipment')
COM_Equipment_MilitaryEquipment = URIRef(NAMESPACE + 'COM.Equipment.MilitaryEquipment')
COM_Equipment_Satellite = URIRef(NAMESPACE + 'COM.Equipment.Satellite')
COM_Flag_Flag = URIRef(NAMESPACE + 'COM.Flag.Flag')
COM_Wreckage_Wreckage = URIRef(NAMESPACE + 'COM.Wreckage.Wreckage')
CRM = URIRef(NAMESPACE + 'CRM')
CRM_BehaviorCrime = URIRef(NAMESPACE + 'CRM.BehaviorCrime')
CRM_BehaviorCrime_FailToAssist = URIRef(NAMESPACE + 'CRM.BehaviorCrime.FailToAssist')
CRM_BehaviorCrime_OrganizedCrime = URIRef(NAMESPACE + 'CRM.BehaviorCrime.OrganizedCrime')
CRM_FinancialCrime = URIRef(NAMESPACE + 'CRM.FinancialCrime')
CRM_FinancialCrime_Extortion = URIRef(NAMESPACE + 'CRM.FinancialCrime.Extortion')
CRM_FinancialCrime_Forgery = URIRef(NAMESPACE + 'CRM.FinancialCrime.Forgery')
CRM_FinancialCrime_Fraud = URIRef(NAMESPACE + 'CRM.FinancialCrime.Fraud')
CRM_PoliticalCrime = URIRef(NAMESPACE + 'CRM.PoliticalCrime')
CRM_PoliticalCrime_AbuseOfOffice = URIRef(NAMESPACE + 'CRM.PoliticalCrime.AbuseOfOffice')
CRM_PoliticalCrime_PoliceMisconduct = URIRef(NAMESPACE + 'CRM.PoliticalCrime.PoliceMisconduct')
CRM_ViolentCrime = URIRef(NAMESPACE + 'CRM.ViolentCrime')
CRM_ViolentCrime_Terrorism = URIRef(NAMESPACE + 'CRM.ViolentCrime.Terrorism')
Conflict_Attack = URIRef(NAMESPACE + 'Conflict.Attack')
Conflict_Attack_AirstrikeMissileStrike = URIRef(NAMESPACE + 'Conflict.Attack.AirstrikeMissileStrike')
Conflict_Attack_BiologicalChemicalPoisonAttack = URIRef(NAMESPACE + 'Conflict.Attack.BiologicalChemicalPoisonAttack')
Conflict_Attack_Bombing = URIRef(NAMESPACE + 'Conflict.Attack.Bombing')
Conflict_Attack_FirearmAttack = URIRef(NAMESPACE + 'Conflict.Attack.FirearmAttack')
Conflict_Attack_Hanging = URIRef(NAMESPACE + 'Conflict.Attack.Hanging')
Conflict_Attack_Invade = URIRef(NAMESPACE + 'Conflict.Attack.Invade')
Conflict_Attack_SelfDirectedBattle = URIRef(NAMESPACE + 'Conflict.Attack.SelfDirectedBattle')
Conflict_Attack_SetFire = URIRef(NAMESPACE + 'Conflict.Attack.SetFire')
Conflict_Attack_Stabbing = URIRef(NAMESPACE + 'Conflict.Attack.Stabbing')
Conflict_Attack_StealRobHijack = URIRef(NAMESPACE + 'Conflict.Attack.StealRobHijack')
Conflict_Attack_Strangling = URIRef(NAMESPACE + 'Conflict.Attack.Strangling')
Conflict_Demonstrate = URIRef(NAMESPACE + 'Conflict.Demonstrate')
Conflict_Demonstrate_MarchProtestPoliticalGathering = URIRef(NAMESPACE + 'Conflict.Demonstrate.MarchProtestPoliticalGathering')
Conflict_Yield = URIRef(NAMESPACE + 'Conflict.Yield')
Conflict_Yield_Retreat = URIRef(NAMESPACE + 'Conflict.Yield.Retreat')
Conflict_Yield_Surrender = URIRef(NAMESPACE + 'Conflict.Yield.Surrender')
Contact_Collaborate = URIRef(NAMESPACE + 'Contact.Collaborate')
Contact_Collaborate_Correspondence = URIRef(NAMESPACE + 'Contact.Collaborate.Correspondence')
Contact_Collaborate_Meet = URIRef(NAMESPACE + 'Contact.Collaborate.Meet')
Contact_CommandOrder = URIRef(NAMESPACE + 'Contact.CommandOrder')
Contact_CommandOrder_Broadcast = URIRef(NAMESPACE + 'Contact.CommandOrder.Broadcast')
Contact_CommandOrder_Correspondence = URIRef(NAMESPACE + 'Contact.CommandOrder.Correspondence')
Contact_CommandOrder_Meet = URIRef(NAMESPACE + 'Contact.CommandOrder.Meet')
Contact_CommitmentPromiseExpressIntent = URIRef(NAMESPACE + 'Contact.CommitmentPromiseExpressIntent')
Contact_CommitmentPromiseExpressIntent_Broadcast = URIRef(NAMESPACE + 'Contact.CommitmentPromiseExpressIntent.Broadcast')
Contact_CommitmentPromiseExpressIntent_Correspondence = URIRef(NAMESPACE + 'Contact.CommitmentPromiseExpressIntent.Correspondence')
Contact_CommitmentPromiseExpressIntent_Meet = URIRef(NAMESPACE + 'Contact.CommitmentPromiseExpressIntent.Meet')
Contact_Discussion = URIRef(NAMESPACE + 'Contact.Discussion')
Contact_Discussion_Correspondence = URIRef(NAMESPACE + 'Contact.Discussion.Correspondence')
Contact_Discussion_Meet = URIRef(NAMESPACE + 'Contact.Discussion.Meet')
Contact_FuneralVigil = URIRef(NAMESPACE + 'Contact.FuneralVigil')
Contact_FuneralVigil_Meet = URIRef(NAMESPACE + 'Contact.FuneralVigil.Meet')
Contact_MediaStatement = URIRef(NAMESPACE + 'Contact.MediaStatement')
Contact_MediaStatement_Broadcast = URIRef(NAMESPACE + 'Contact.MediaStatement.Broadcast')
Contact_Negotiate = URIRef(NAMESPACE + 'Contact.Negotiate')
Contact_Negotiate_Correspondence = URIRef(NAMESPACE + 'Contact.Negotiate.Correspondence')
Contact_Negotiate_Meet = URIRef(NAMESPACE + 'Contact.Negotiate.Meet')
Contact_Prevarication = URIRef(NAMESPACE + 'Contact.Prevarication')
Contact_Prevarication_Broadcast = URIRef(NAMESPACE + 'Contact.Prevarication.Broadcast')
Contact_Prevarication_Correspondence = URIRef(NAMESPACE + 'Contact.Prevarication.Correspondence')
Contact_Prevarication_Meet = URIRef(NAMESPACE + 'Contact.Prevarication.Meet')
Contact_PublicStatementInPerson = URIRef(NAMESPACE + 'Contact.PublicStatementInPerson')
Contact_PublicStatementInPerson_Broadcast = URIRef(NAMESPACE + 'Contact.PublicStatementInPerson.Broadcast')
Contact_RequestAdvise = URIRef(NAMESPACE + 'Contact.RequestAdvise')
Contact_RequestAdvise_Broadcast = URIRef(NAMESPACE + 'Contact.RequestAdvise.Broadcast')
Contact_RequestAdvise_Correspondence = URIRef(NAMESPACE + 'Contact.RequestAdvise.Correspondence')
Contact_RequestAdvise_Meet = URIRef(NAMESPACE + 'Contact.RequestAdvise.Meet')
Contact_ThreatenCoerce = URIRef(NAMESPACE + 'Contact.ThreatenCoerce')
Contact_ThreatenCoerce_Broadcast = URIRef(NAMESPACE + 'Contact.ThreatenCoerce.Broadcast')
Contact_ThreatenCoerce_Correspondence = URIRef(NAMESPACE + 'Contact.ThreatenCoerce.Correspondence')
Contact_ThreatenCoerce_Meet = URIRef(NAMESPACE + 'Contact.ThreatenCoerce.Meet')
Disaster_AccidentCrash_AccidentCrash = URIRef(NAMESPACE + 'Disaster.AccidentCrash.AccidentCrash')
Disaster_FireExplosion_FireExplosion = URIRef(NAMESPACE + 'Disaster.FireExplosion.FireExplosion')
Evaluate_Deliberateness_Accidental = URIRef(NAMESPACE + 'Evaluate.Deliberateness.Accidental')
Evaluate_Deliberateness_Deliberate = URIRef(NAMESPACE + 'Evaluate.Deliberateness.Deliberate')
Evaluate_Legitimacy_Illegitimate = URIRef(NAMESPACE + 'Evaluate.Legitimacy.Illegitimate')
Evaluate_Legitimacy_Legitimate = URIRef(NAMESPACE + 'Evaluate.Legitimacy.Legitimate')
Evaluate_Sentiment_Negative = URIRef(NAMESPACE + 'Evaluate.Sentiment.Negative')
Evaluate_Sentiment_Positive = URIRef(NAMESPACE + 'Evaluate.Sentiment.Positive')
FAC = URIRef(NAMESPACE + 'FAC')
FAC_Building = URIRef(NAMESPACE + 'FAC.Building')
FAC_Building_ApartmentBuilding = URIRef(NAMESPACE + 'FAC.Building.ApartmentBuilding')
FAC_Building_GovernmentBuilding = URIRef(NAMESPACE + 'FAC.Building.GovernmentBuilding')
FAC_Building_House = URIRef(NAMESPACE + 'FAC.Building.House')
FAC_Building_OfficeBuilding = URIRef(NAMESPACE + 'FAC.Building.OfficeBuilding')
FAC_Building_School = URIRef(NAMESPACE + 'FAC.Building.School')
FAC_Building_StoreShop = URIRef(NAMESPACE + 'FAC.Building.StoreShop')
FAC_Building_VotingFacility = URIRef(NAMESPACE + 'FAC.Building.VotingFacility')
FAC_GeographicalArea = URIRef(NAMESPACE + 'FAC.GeographicalArea')
FAC_GeographicalArea_Border = URIRef(NAMESPACE + 'FAC.GeographicalArea.Border')
FAC_GeographicalArea_Checkpoint = URIRef(NAMESPACE + 'FAC.GeographicalArea.Checkpoint')
FAC_Installation = URIRef(NAMESPACE + 'FAC.Installation')
FAC_Installation_Airport = URIRef(NAMESPACE + 'FAC.Installation.Airport')
FAC_Installation_MilitaryInstallation = URIRef(NAMESPACE + 'FAC.Installation.MilitaryInstallation')
FAC_Installation_TrainStation = URIRef(NAMESPACE + 'FAC.Installation.TrainStation')
FAC_Structure = URIRef(NAMESPACE + 'FAC.Structure')
FAC_Structure_Barricade = URIRef(NAMESPACE + 'FAC.Structure.Barricade')
FAC_Structure_Bridge = URIRef(NAMESPACE + 'FAC.Structure.Bridge')
FAC_Structure_Plaza = URIRef(NAMESPACE + 'FAC.Structure.Plaza')
FAC_Structure_Tower = URIRef(NAMESPACE + 'FAC.Structure.Tower')
FAC_Way = URIRef(NAMESPACE + 'FAC.Way')
FAC_Way_Highway = URIRef(NAMESPACE + 'FAC.Way.Highway')
FAC_Way_Street = URIRef(NAMESPACE + 'FAC.Way.Street')
GPE = URIRef(NAMESPACE + 'GPE')
GPE_Country_Country = URIRef(NAMESPACE + 'GPE.Country.Country')
GPE_OrganizationOfCountries_OrganizationOfCountries = URIRef(NAMESPACE + 'GPE.OrganizationOfCountries.OrganizationOfCountries')
GPE_ProvinceState_ProvinceState = URIRef(NAMESPACE + 'GPE.ProvinceState.ProvinceState')
GPE_UrbanArea = URIRef(NAMESPACE + 'GPE.UrbanArea')
GPE_UrbanArea_City = URIRef(NAMESPACE + 'GPE.UrbanArea.City')
GPE_UrbanArea_Village = URIRef(NAMESPACE + 'GPE.UrbanArea.Village')
GeneralAffiliation_ArtifactPoliticalOrganizationReligiousAffiliation = URIRef(NAMESPACE + 'GeneralAffiliation.ArtifactPoliticalOrganizationReligiousAffiliation')
GeneralAffiliation_ArtifactPoliticalOrganizationReligiousAffiliation_ControlTerritory = URIRef(NAMESPACE + 'GeneralAffiliation.ArtifactPoliticalOrganizationReligiousAffiliation.ControlTerritory')
GeneralAffiliation_ArtifactPoliticalOrganizationReligiousAffiliation_NationalityCitizen = URIRef(NAMESPACE + 'GeneralAffiliation.ArtifactPoliticalOrganizationReligiousAffiliation.NationalityCitizen')
GeneralAffiliation_ArtifactPoliticalOrganizationReligiousAffiliation_OwnershipPossession = URIRef(NAMESPACE + 'GeneralAffiliation.ArtifactPoliticalOrganizationReligiousAffiliation.OwnershipPossession')
GeneralAffiliation_MemberOriginReligionEthnicity = URIRef(NAMESPACE + 'GeneralAffiliation.MemberOriginReligionEthnicity')
GeneralAffiliation_MemberOriginReligionEthnicity_Ethnicity = URIRef(NAMESPACE + 'GeneralAffiliation.MemberOriginReligionEthnicity.Ethnicity')
GeneralAffiliation_MemberOriginReligionEthnicity_NationalityCitizen = URIRef(NAMESPACE + 'GeneralAffiliation.MemberOriginReligionEthnicity.NationalityCitizen')
GeneralAffiliation_OrganizationPoliticalReligiousAffiliation = URIRef(NAMESPACE + 'GeneralAffiliation.OrganizationPoliticalReligiousAffiliation')
GeneralAffiliation_OrganizationPoliticalReligiousAffiliation_NationalityCitizen = URIRef(NAMESPACE + 'GeneralAffiliation.OrganizationPoliticalReligiousAffiliation.NationalityCitizen')
GeneralAffiliation_OrganizationWebsite_OrganizationWebsite = URIRef(NAMESPACE + 'GeneralAffiliation.OrganizationWebsite.OrganizationWebsite')
GeneralAffiliation_Sponsorship = URIRef(NAMESPACE + 'GeneralAffiliation.Sponsorship')
GeneralAffiliation_Sponsorship_AdvisePlanOrganize = URIRef(NAMESPACE + 'GeneralAffiliation.Sponsorship.AdvisePlanOrganize')
GeneralAffiliation_Sponsorship_Affiliated = URIRef(NAMESPACE + 'GeneralAffiliation.Sponsorship.Affiliated')
GeneralAffiliation_Sponsorship_HelpSupport = URIRef(NAMESPACE + 'GeneralAffiliation.Sponsorship.HelpSupport')
Government_Agreements = URIRef(NAMESPACE + 'Government.Agreements')
Government_Agreements_AcceptAgreementContractCeasefire = URIRef(NAMESPACE + 'Government.Agreements.AcceptAgreementContractCeasefire')
Government_Agreements_RejectNullifyAgreementContractCeasefire = URIRef(NAMESPACE + 'Government.Agreements.RejectNullifyAgreementContractCeasefire')
Government_Agreements_ViolateAgreement = URIRef(NAMESPACE + 'Government.Agreements.ViolateAgreement')
Government_Formation = URIRef(NAMESPACE + 'Government.Formation')
Government_Formation_MergeGPE = URIRef(NAMESPACE + 'Government.Formation.MergeGPE')
Government_Formation_StartGPE = URIRef(NAMESPACE + 'Government.Formation.StartGPE')
Government_Legislate_Legislate = URIRef(NAMESPACE + 'Government.Legislate.Legislate')
Government_Spy_Spy = URIRef(NAMESPACE + 'Government.Spy.Spy')
Government_Vote = URIRef(NAMESPACE + 'Government.Vote')
Government_Vote_CastVote = URIRef(NAMESPACE + 'Government.Vote.CastVote')
Government_Vote_ViolationsPreventVote = URIRef(NAMESPACE + 'Government.Vote.ViolationsPreventVote')
Information_Color_Color = URIRef(NAMESPACE + 'Information.Color.Color')
Information_Make_Make = URIRef(NAMESPACE + 'Information.Make.Make')
Inspection_SensoryObserve = URIRef(NAMESPACE + 'Inspection.SensoryObserve')
Inspection_SensoryObserve_InspectPeopleOrganization = URIRef(NAMESPACE + 'Inspection.SensoryObserve.InspectPeopleOrganization')
Inspection_SensoryObserve_MonitorElection = URIRef(NAMESPACE + 'Inspection.SensoryObserve.MonitorElection')
Inspection_SensoryObserve_PhysicalInvestigateInspect = URIRef(NAMESPACE + 'Inspection.SensoryObserve.PhysicalInvestigateInspect')
Justice_ArrestJailDetain_ArrestJailDetain = URIRef(NAMESPACE + 'Justice.ArrestJailDetain.ArrestJailDetain')
Justice_InitiateJudicialProcess = URIRef(NAMESPACE + 'Justice.InitiateJudicialProcess')
Justice_InitiateJudicialProcess_ChargeIndict = URIRef(NAMESPACE + 'Justice.InitiateJudicialProcess.ChargeIndict')
Justice_InitiateJudicialProcess_TrialHearing = URIRef(NAMESPACE + 'Justice.InitiateJudicialProcess.TrialHearing')
Justice_Investigate = URIRef(NAMESPACE + 'Justice.Investigate')
Justice_Investigate_InvestigateCrime = URIRef(NAMESPACE + 'Justice.Investigate.InvestigateCrime')
Justice_JudicialConsequences = URIRef(NAMESPACE + 'Justice.JudicialConsequences')
Justice_JudicialConsequences_Convict = URIRef(NAMESPACE + 'Justice.JudicialConsequences.Convict')
Justice_JudicialConsequences_Execute = URIRef(NAMESPACE + 'Justice.JudicialConsequences.Execute')
Justice_JudicialConsequences_Extradite = URIRef(NAMESPACE + 'Justice.JudicialConsequences.Extradite')
LAW = URIRef(NAMESPACE + 'LAW')
LAW_Referendum_Referendum = URIRef(NAMESPACE + 'LAW.Referendum.Referendum')
LOC = URIRef(NAMESPACE + 'LOC')
LOC_GeographicPoint = URIRef(NAMESPACE + 'LOC.GeographicPoint')
LOC_GeographicPoint_Address = URIRef(NAMESPACE + 'LOC.GeographicPoint.Address')
LOC_Land = URIRef(NAMESPACE + 'LOC.Land')
LOC_Land_Continent = URIRef(NAMESPACE + 'LOC.Land.Continent')
LOC_Position = URIRef(NAMESPACE + 'LOC.Position')
LOC_Position_AirSpace = URIRef(NAMESPACE + 'LOC.Position.AirSpace')
LOC_Position_CrimeScene = URIRef(NAMESPACE + 'LOC.Position.CrimeScene')
LOC_Position_Field = URIRef(NAMESPACE + 'LOC.Position.Field')
LOC_Position_Neighborhood = URIRef(NAMESPACE + 'LOC.Position.Neighborhood')
LOC_Position_Region = URIRef(NAMESPACE + 'LOC.Position.Region')
Life_Die = URIRef(NAMESPACE + 'Life.Die')
Life_Die_DeathCausedByViolentEvents = URIRef(NAMESPACE + 'Life.Die.DeathCausedByViolentEvents')
Life_Die_NonviolentDeath = URIRef(NAMESPACE + 'Life.Die.NonviolentDeath')
Life_Injure = URIRef(NAMESPACE + 'Life.Injure')
Life_Injure_IllnessDegradationHungerThirst = URIRef(NAMESPACE + 'Life.Injure.IllnessDegradationHungerThirst')
Life_Injure_IllnessDegradationPhysical = URIRef(NAMESPACE + 'Life.Injure.IllnessDegradationPhysical')
Life_Injure_InjuryCausedByViolentEvents = URIRef(NAMESPACE + 'Life.Injure.InjuryCausedByViolentEvents')
MON = URIRef(NAMESPACE + 'MON')
MON_Assets_Assets = URIRef(NAMESPACE + 'MON.Assets.Assets')
MON_Cash_Cash = URIRef(NAMESPACE + 'MON.Cash.Cash')
Manufacture_Artifact = URIRef(NAMESPACE + 'Manufacture.Artifact')
Manufacture_Artifact_Build = URIRef(NAMESPACE + 'Manufacture.Artifact.Build')
Manufacture_Artifact_CreateIntellectualProperty = URIRef(NAMESPACE + 'Manufacture.Artifact.CreateIntellectualProperty')
Manufacture_Artifact_CreateManufacture = URIRef(NAMESPACE + 'Manufacture.Artifact.CreateManufacture')
Measurement_Size = URIRef(NAMESPACE + 'Measurement.Size')
Measurement_Size_Count = URIRef(NAMESPACE + 'Measurement.Size.Count')
Measurement_Size_HeightLengthWidth = URIRef(NAMESPACE + 'Measurement.Size.HeightLengthWidth')
Measurement_Size_Percentage = URIRef(NAMESPACE + 'Measurement.Size.Percentage')
Measurement_Size_Weight = URIRef(NAMESPACE + 'Measurement.Size.Weight')
Movement_TransportArtifact = URIRef(NAMESPACE + 'Movement.TransportArtifact')
Movement_TransportArtifact_BringCarryUnload = URIRef(NAMESPACE + 'Movement.TransportArtifact.BringCarryUnload')
Movement_TransportArtifact_DisperseSeparate = URIRef(NAMESPACE + 'Movement.TransportArtifact.DisperseSeparate')
Movement_TransportArtifact_Fall = URIRef(NAMESPACE + 'Movement.TransportArtifact.Fall')
Movement_TransportArtifact_GrantEntry = URIRef(NAMESPACE + 'Movement.TransportArtifact.GrantEntry')
Movement_TransportArtifact_Hide = URIRef(NAMESPACE + 'Movement.TransportArtifact.Hide')
Movement_TransportArtifact_NonviolentThrowLaunch = URIRef(NAMESPACE + 'Movement.TransportArtifact.NonviolentThrowLaunch')
Movement_TransportArtifact_PreventEntry = URIRef(NAMESPACE + 'Movement.TransportArtifact.PreventEntry')
Movement_TransportArtifact_PreventExit = URIRef(NAMESPACE + 'Movement.TransportArtifact.PreventExit')
Movement_TransportArtifact_ReceiveImport = URIRef(NAMESPACE + 'Movement.TransportArtifact.ReceiveImport')
Movement_TransportArtifact_SendSupplyExport = URIRef(NAMESPACE + 'Movement.TransportArtifact.SendSupplyExport')
Movement_TransportArtifact_SmuggleExtract = URIRef(NAMESPACE + 'Movement.TransportArtifact.SmuggleExtract')
Movement_TransportPerson = URIRef(NAMESPACE + 'Movement.TransportPerson')
Movement_TransportPerson_BringCarryUnload = URIRef(NAMESPACE + 'Movement.TransportPerson.BringCarryUnload')
Movement_TransportPerson_DisperseSeparate = URIRef(NAMESPACE + 'Movement.TransportPerson.DisperseSeparate')
Movement_TransportPerson_EvacuationRescue = URIRef(NAMESPACE + 'Movement.TransportPerson.EvacuationRescue')
Movement_TransportPerson_Fall = URIRef(NAMESPACE + 'Movement.TransportPerson.Fall')
Movement_TransportPerson_GrantEntryAsylum = URIRef(NAMESPACE + 'Movement.TransportPerson.GrantEntryAsylum')
Movement_TransportPerson_Hide = URIRef(NAMESPACE + 'Movement.TransportPerson.Hide')
Movement_TransportPerson_PreventEntry = URIRef(NAMESPACE + 'Movement.TransportPerson.PreventEntry')
Movement_TransportPerson_PreventExit = URIRef(NAMESPACE + 'Movement.TransportPerson.PreventExit')
Movement_TransportPerson_SelfMotion = URIRef(NAMESPACE + 'Movement.TransportPerson.SelfMotion')
Movement_TransportPerson_SmuggleExtract = URIRef(NAMESPACE + 'Movement.TransportPerson.SmuggleExtract')
ORG = URIRef(NAMESPACE + 'ORG')
ORG_Association = URIRef(NAMESPACE + 'ORG.Association')
ORG_Association_Club = URIRef(NAMESPACE + 'ORG.Association.Club')
ORG_Association_Team = URIRef(NAMESPACE + 'ORG.Association.Team')
ORG_CommercialOrganization = URIRef(NAMESPACE + 'ORG.CommercialOrganization')
ORG_CommercialOrganization_BroadcastingCompany = URIRef(NAMESPACE + 'ORG.CommercialOrganization.BroadcastingCompany')
ORG_CommercialOrganization_Corporation = URIRef(NAMESPACE + 'ORG.CommercialOrganization.Corporation')
ORG_CommercialOrganization_Manufacturer = URIRef(NAMESPACE + 'ORG.CommercialOrganization.Manufacturer')
ORG_CommercialOrganization_NewsAgency = URIRef(NAMESPACE + 'ORG.CommercialOrganization.NewsAgency')
ORG_CriminalOrganization_CriminalOrganization = URIRef(NAMESPACE + 'ORG.CriminalOrganization.CriminalOrganization')
ORG_Government = URIRef(NAMESPACE + 'ORG.Government')
ORG_Government_Agency = URIRef(NAMESPACE + 'ORG.Government.Agency')
ORG_Government_Council = URIRef(NAMESPACE + 'ORG.Government.Council')
ORG_Government_FireDepartment = URIRef(NAMESPACE + 'ORG.Government.FireDepartment')
ORG_Government_LawEnforcementAgency = URIRef(NAMESPACE + 'ORG.Government.LawEnforcementAgency')
ORG_Government_LegislativeBody = URIRef(NAMESPACE + 'ORG.Government.LegislativeBody')
ORG_Government_ProsecutorOffice = URIRef(NAMESPACE + 'ORG.Government.ProsecutorOffice')
ORG_Government_Railway = URIRef(NAMESPACE + 'ORG.Government.Railway')
ORG_International = URIRef(NAMESPACE + 'ORG.International')
ORG_International_Commission = URIRef(NAMESPACE + 'ORG.International.Commission')
ORG_International_MonitoringGroup = URIRef(NAMESPACE + 'ORG.International.MonitoringGroup')
ORG_MilitaryOrganization = URIRef(NAMESPACE + 'ORG.MilitaryOrganization')
ORG_MilitaryOrganization_GovernmentArmedForces = URIRef(NAMESPACE + 'ORG.MilitaryOrganization.GovernmentArmedForces')
ORG_MilitaryOrganization_Intelligence = URIRef(NAMESPACE + 'ORG.MilitaryOrganization.Intelligence')
ORG_MilitaryOrganization_NonGovernmentMilitia = URIRef(NAMESPACE + 'ORG.MilitaryOrganization.NonGovernmentMilitia')
ORG_PoliticalOrganization = URIRef(NAMESPACE + 'ORG.PoliticalOrganization')
ORG_PoliticalOrganization_Court = URIRef(NAMESPACE + 'ORG.PoliticalOrganization.Court')
ORG_PoliticalOrganization_Party = URIRef(NAMESPACE + 'ORG.PoliticalOrganization.Party')
OrganizationAffiliation_EmploymentMembership = URIRef(NAMESPACE + 'OrganizationAffiliation.EmploymentMembership')
OrganizationAffiliation_EmploymentMembership_Employment = URIRef(NAMESPACE + 'OrganizationAffiliation.EmploymentMembership.Employment')
OrganizationAffiliation_EmploymentMembership_Membership = URIRef(NAMESPACE + 'OrganizationAffiliation.EmploymentMembership.Membership')
OrganizationAffiliation_Founder_Founder = URIRef(NAMESPACE + 'OrganizationAffiliation.Founder.Founder')
OrganizationAffiliation_Leadership = URIRef(NAMESPACE + 'OrganizationAffiliation.Leadership')
OrganizationAffiliation_Leadership_Government = URIRef(NAMESPACE + 'OrganizationAffiliation.Leadership.Government')
OrganizationAffiliation_Leadership_HeadOfState = URIRef(NAMESPACE + 'OrganizationAffiliation.Leadership.HeadOfState')
OrganizationAffiliation_Leadership_MilitaryPolice = URIRef(NAMESPACE + 'OrganizationAffiliation.Leadership.MilitaryPolice')
PER = URIRef(NAMESPACE + 'PER')
PER_Combatant = URIRef(NAMESPACE + 'PER.Combatant')
PER_Combatant_Mercenary = URIRef(NAMESPACE + 'PER.Combatant.Mercenary')
PER_Combatant_Sniper = URIRef(NAMESPACE + 'PER.Combatant.Sniper')
PER_Fan = URIRef(NAMESPACE + 'PER.Fan')
PER_Fan_SportsFan = URIRef(NAMESPACE + 'PER.Fan.SportsFan')
PER_MilitaryPersonnel = URIRef(NAMESPACE + 'PER.MilitaryPersonnel')
PER_MilitaryPersonnel_MilitaryOfficer = URIRef(NAMESPACE + 'PER.MilitaryPersonnel.MilitaryOfficer')
PER_Police = URIRef(NAMESPACE + 'PER.Police')
PER_Police_ChiefOfPolice = URIRef(NAMESPACE + 'PER.Police.ChiefOfPolice')
PER_Politician = URIRef(NAMESPACE + 'PER.Politician')
PER_Politician_Governor = URIRef(NAMESPACE + 'PER.Politician.Governor')
PER_Politician_HeadOfGovernment = URIRef(NAMESPACE + 'PER.Politician.HeadOfGovernment')
PER_Politician_Mayor = URIRef(NAMESPACE + 'PER.Politician.Mayor')
PER_ProfessionalPosition = URIRef(NAMESPACE + 'PER.ProfessionalPosition')
PER_ProfessionalPosition_Ambassador = URIRef(NAMESPACE + 'PER.ProfessionalPosition.Ambassador')
PER_ProfessionalPosition_Firefighter = URIRef(NAMESPACE + 'PER.ProfessionalPosition.Firefighter')
PER_ProfessionalPosition_Journalist = URIRef(NAMESPACE + 'PER.ProfessionalPosition.Journalist')
PER_ProfessionalPosition_Minister = URIRef(NAMESPACE + 'PER.ProfessionalPosition.Minister')
PER_ProfessionalPosition_Paramedic = URIRef(NAMESPACE + 'PER.ProfessionalPosition.Paramedic')
PER_ProfessionalPosition_Scientist = URIRef(NAMESPACE + 'PER.ProfessionalPosition.Scientist')
PER_ProfessionalPosition_Spokesperson = URIRef(NAMESPACE + 'PER.ProfessionalPosition.Spokesperson')
PER_ProfessionalPosition_Spy = URIRef(NAMESPACE + 'PER.ProfessionalPosition.Spy')
PER_Protester = URIRef(NAMESPACE + 'PER.Protester')
PER_Protester_ProtestLeader = URIRef(NAMESPACE + 'PER.Protester.ProtestLeader')
PartWhole_Subsidiary = URIRef(NAMESPACE + 'PartWhole.Subsidiary')
PartWhole_Subsidiary_NationalityCitizen = URIRef(NAMESPACE + 'PartWhole.Subsidiary.NationalityCitizen')
PartWhole_Subsidiary_OrganizationSubsidiary = URIRef(NAMESPACE + 'PartWhole.Subsidiary.OrganizationSubsidiary')
PersonalSocial_Role = URIRef(NAMESPACE + 'PersonalSocial.Role')
PersonalSocial_Role_ProfessionalRole = URIRef(NAMESPACE + 'PersonalSocial.Role.ProfessionalRole')
PersonalSocial_Role_TitleFormOfAddress = URIRef(NAMESPACE + 'PersonalSocial.Role.TitleFormOfAddress')
PersonalSocial_Unspecified = URIRef(NAMESPACE + 'PersonalSocial.Unspecified')
PersonalSocial_Unspecified_Political = URIRef(NAMESPACE + 'PersonalSocial.Unspecified.Political')
Personnel_Elect = URIRef(NAMESPACE + 'Personnel.Elect')
Personnel_Elect_WinElection = URIRef(NAMESPACE + 'Personnel.Elect.WinElection')
Personnel_EndPosition = URIRef(NAMESPACE + 'Personnel.EndPosition')
Personnel_EndPosition_FiringLayoff = URIRef(NAMESPACE + 'Personnel.EndPosition.FiringLayoff')
Personnel_EndPosition_QuitRetire = URIRef(NAMESPACE + 'Personnel.EndPosition.QuitRetire')
Personnel_StartPosition = URIRef(NAMESPACE + 'Personnel.StartPosition')
Personnel_StartPosition_Hiring = URIRef(NAMESPACE + 'Personnel.StartPosition.Hiring')
Physical_LocatedNear = URIRef(NAMESPACE + 'Physical.LocatedNear')
Physical_LocatedNear_Surround = URIRef(NAMESPACE + 'Physical.LocatedNear.Surround')
Physical_OrganizationHeadquarters_OrganizationHeadquarters = URIRef(NAMESPACE + 'Physical.OrganizationHeadquarters.OrganizationHeadquarters')
Physical_Resident_Resident = URIRef(NAMESPACE + 'Physical.Resident.Resident')
RES = URIRef(NAMESPACE + 'RES')
RES_NumberPercentageVotes_NumberPercentageVotes = URIRef(NAMESPACE + 'RES.NumberPercentageVotes.NumberPercentageVotes')
RES_TurnoutVoters_TurnoutVoters = URIRef(NAMESPACE + 'RES.TurnoutVoters.TurnoutVoters')
ResponsibilityBlame_AssignBlame_AssignBlame = URIRef(NAMESPACE + 'ResponsibilityBlame.AssignBlame.AssignBlame')
ResponsibilityBlame_ClaimResponsibility_ClaimResponsibility = URIRef(NAMESPACE + 'ResponsibilityBlame.ClaimResponsibility.ClaimResponsibility')
SID = URIRef(NAMESPACE + 'SID')
SID_Cultural_Cultural = URIRef(NAMESPACE + 'SID.Cultural.Cultural')
SID_Ideological_Ideological = URIRef(NAMESPACE + 'SID.Ideological.Ideological')
SID_Political_Opposition = URIRef(NAMESPACE + 'SID.Political.Opposition')
SID_Religious_Religious = URIRef(NAMESPACE + 'SID.Religious.Religious')
SID_Sports_Sports = URIRef(NAMESPACE + 'SID.Sports.Sports')
TTL = URIRef(NAMESPACE + 'TTL')
Transaction_Transaction = URIRef(NAMESPACE + 'Transaction.Transaction')
Transaction_Transaction_EmbargoSanction = URIRef(NAMESPACE + 'Transaction.Transaction.EmbargoSanction')
Transaction_Transaction_GiftGrantProvideAid = URIRef(NAMESPACE + 'Transaction.Transaction.GiftGrantProvideAid')
Transaction_Transaction_TransferControl = URIRef(NAMESPACE + 'Transaction.Transaction.TransferControl')
Transaction_TransferMoney = URIRef(NAMESPACE + 'Transaction.TransferMoney')
Transaction_TransferMoney_BorrowLend = URIRef(NAMESPACE + 'Transaction.TransferMoney.BorrowLend')
Transaction_TransferMoney_EmbargoSanction = URIRef(NAMESPACE + 'Transaction.TransferMoney.EmbargoSanction')
Transaction_TransferMoney_GiftGrantProvideAid = URIRef(NAMESPACE + 'Transaction.TransferMoney.GiftGrantProvideAid')
Transaction_TransferMoney_PayForService = URIRef(NAMESPACE + 'Transaction.TransferMoney.PayForService')
Transaction_TransferMoney_Purchase = URIRef(NAMESPACE + 'Transaction.TransferMoney.Purchase')
Transaction_TransferOwnership = URIRef(NAMESPACE + 'Transaction.TransferOwnership')
Transaction_TransferOwnership_BorrowLend = URIRef(NAMESPACE + 'Transaction.TransferOwnership.BorrowLend')
Transaction_TransferOwnership_EmbargoSanction = URIRef(NAMESPACE + 'Transaction.TransferOwnership.EmbargoSanction')
Transaction_TransferOwnership_GiftGrantProvideAid = URIRef(NAMESPACE + 'Transaction.TransferOwnership.GiftGrantProvideAid')
Transaction_TransferOwnership_Purchase = URIRef(NAMESPACE + 'Transaction.TransferOwnership.Purchase')
VAL = URIRef(NAMESPACE + 'VAL')
VAL_Number_Number = URIRef(NAMESPACE + 'VAL.Number.Number')
VEH = URIRef(NAMESPACE + 'VEH')
VEH_Aircraft = URIRef(NAMESPACE + 'VEH.Aircraft')
VEH_Aircraft_Airplane = URIRef(NAMESPACE + 'VEH.Aircraft.Airplane')
VEH_Aircraft_CargoAircraft = URIRef(NAMESPACE + 'VEH.Aircraft.CargoAircraft')
VEH_Aircraft_Helicopter = URIRef(NAMESPACE + 'VEH.Aircraft.Helicopter')
VEH_MilitaryVehicle = URIRef(NAMESPACE + 'VEH.MilitaryVehicle')
VEH_MilitaryVehicle_FighterAircraft = URIRef(NAMESPACE + 'VEH.MilitaryVehicle.FighterAircraft')
VEH_MilitaryVehicle_MilitaryBoat = URIRef(NAMESPACE + 'VEH.MilitaryVehicle.MilitaryBoat')
VEH_MilitaryVehicle_MilitaryTransportAircraft = URIRef(NAMESPACE + 'VEH.MilitaryVehicle.MilitaryTransportAircraft')
VEH_MilitaryVehicle_Tank = URIRef(NAMESPACE + 'VEH.MilitaryVehicle.Tank')
VEH_Rocket_Rocket = URIRef(NAMESPACE + 'VEH.Rocket.Rocket')
VEH_Watercraft = URIRef(NAMESPACE + 'VEH.Watercraft')
VEH_Watercraft_Boat = URIRef(NAMESPACE + 'VEH.Watercraft.Boat')
VEH_Watercraft_Yacht = URIRef(NAMESPACE + 'VEH.Watercraft.Yacht')
VEH_WheeledVehicle = URIRef(NAMESPACE + 'VEH.WheeledVehicle')
VEH_WheeledVehicle_Bus = URIRef(NAMESPACE + 'VEH.WheeledVehicle.Bus')
VEH_WheeledVehicle_Car = URIRef(NAMESPACE + 'VEH.WheeledVehicle.Car')
VEH_WheeledVehicle_FireApparatus = URIRef(NAMESPACE + 'VEH.WheeledVehicle.FireApparatus')
VEH_WheeledVehicle_Train = URIRef(NAMESPACE + 'VEH.WheeledVehicle.Train')
VEH_WheeledVehicle_Truck = URIRef(NAMESPACE + 'VEH.WheeledVehicle.Truck')
WEA = URIRef(NAMESPACE + 'WEA')
WEA_Bomb = URIRef(NAMESPACE + 'WEA.Bomb')
WEA_Bomb_Grenade = URIRef(NAMESPACE + 'WEA.Bomb.Grenade')
WEA_Bomb_MolotovCocktail = URIRef(NAMESPACE + 'WEA.Bomb.MolotovCocktail')
WEA_Bullets = URIRef(NAMESPACE + 'WEA.Bullets')
WEA_Bullets_Ammunition = URIRef(NAMESPACE + 'WEA.Bullets.Ammunition')
WEA_Bullets_LiveRounds = URIRef(NAMESPACE + 'WEA.Bullets.LiveRounds')
WEA_Bullets_RubberBullets = URIRef(NAMESPACE + 'WEA.Bullets.RubberBullets')
WEA_Cannon_Cannon = URIRef(NAMESPACE + 'WEA.Cannon.Cannon')
WEA_Club = URIRef(NAMESPACE + 'WEA.Club')
WEA_Club_Bat = URIRef(NAMESPACE + 'WEA.Club.Bat')
WEA_DaggerKnifeSword = URIRef(NAMESPACE + 'WEA.DaggerKnifeSword')
WEA_DaggerKnifeSword_Hatchet = URIRef(NAMESPACE + 'WEA.DaggerKnifeSword.Hatchet')
WEA_Gas = URIRef(NAMESPACE + 'WEA.Gas')
WEA_Gas_PoisonGas = URIRef(NAMESPACE + 'WEA.Gas.PoisonGas')
WEA_Gas_TearGas = URIRef(NAMESPACE + 'WEA.Gas.TearGas')
WEA_GrenadeLauncher_GrenadeLauncher = URIRef(NAMESPACE + 'WEA.GrenadeLauncher.GrenadeLauncher')
WEA_Gun = URIRef(NAMESPACE + 'WEA.Gun')
WEA_Gun_Artillery = URIRef(NAMESPACE + 'WEA.Gun.Artillery')
WEA_Gun_Firearm = URIRef(NAMESPACE + 'WEA.Gun.Firearm')
WEA_MissileSystem = URIRef(NAMESPACE + 'WEA.MissileSystem')
WEA_MissileSystem_AirToAirMissile = URIRef(NAMESPACE + 'WEA.MissileSystem.AirToAirMissile')
WEA_MissileSystem_AntiAircraftMissle = URIRef(NAMESPACE + 'WEA.MissileSystem.AntiAircraftMissle')
WEA_MissileSystem_Missile = URIRef(NAMESPACE + 'WEA.MissileSystem.Missile')
WEA_MissileSystem_MissileLauncher = URIRef(NAMESPACE + 'WEA.MissileSystem.MissileLauncher')
WEA_MissileSystem_SurfaceToAirMissile = URIRef(NAMESPACE + 'WEA.MissileSystem.SurfaceToAirMissile')
WEA_ThrownProjectile = URIRef(NAMESPACE + 'WEA.ThrownProjectile')
WEA_ThrownProjectile_Rock = URIRef(NAMESPACE + 'WEA.ThrownProjectile.Rock')

# Properties
ArtifactExistence_DamageDestroy_Artifact = URIRef(NAMESPACE + 'ArtifactExistence.DamageDestroy_Artifact')
ArtifactExistence_DamageDestroy_Damage_Artifact = URIRef(NAMESPACE + 'ArtifactExistence.DamageDestroy.Damage_Artifact')
ArtifactExistence_DamageDestroy_Damage_Damager = URIRef(NAMESPACE + 'ArtifactExistence.DamageDestroy.Damage_Damager')
ArtifactExistence_DamageDestroy_Damage_Instrument = URIRef(NAMESPACE + 'ArtifactExistence.DamageDestroy.Damage_Instrument')
ArtifactExistence_DamageDestroy_Damage_Place = URIRef(NAMESPACE + 'ArtifactExistence.DamageDestroy.Damage_Place')
ArtifactExistence_DamageDestroy_DamagerDestroyer = URIRef(NAMESPACE + 'ArtifactExistence.DamageDestroy_DamagerDestroyer')
ArtifactExistence_DamageDestroy_Destroy_Artifact = URIRef(NAMESPACE + 'ArtifactExistence.DamageDestroy.Destroy_Artifact')
ArtifactExistence_DamageDestroy_Destroy_Destroyer = URIRef(NAMESPACE + 'ArtifactExistence.DamageDestroy.Destroy_Destroyer')
ArtifactExistence_DamageDestroy_Destroy_Instrument = URIRef(NAMESPACE + 'ArtifactExistence.DamageDestroy.Destroy_Instrument')
ArtifactExistence_DamageDestroy_Destroy_Place = URIRef(NAMESPACE + 'ArtifactExistence.DamageDestroy.Destroy_Place')
ArtifactExistence_DamageDestroy_Instrument = URIRef(NAMESPACE + 'ArtifactExistence.DamageDestroy_Instrument')
ArtifactExistence_DamageDestroy_Place = URIRef(NAMESPACE + 'ArtifactExistence.DamageDestroy_Place')
Conflict_Attack_AirstrikeMissileStrike_Attacker = URIRef(NAMESPACE + 'Conflict.Attack.AirstrikeMissileStrike_Attacker')
Conflict_Attack_AirstrikeMissileStrike_Instrument = URIRef(NAMESPACE + 'Conflict.Attack.AirstrikeMissileStrike_Instrument')
Conflict_Attack_AirstrikeMissileStrike_Place = URIRef(NAMESPACE + 'Conflict.Attack.AirstrikeMissileStrike_Place')
Conflict_Attack_AirstrikeMissileStrike_Target = URIRef(NAMESPACE + 'Conflict.Attack.AirstrikeMissileStrike_Target')
Conflict_Attack_Attacker = URIRef(NAMESPACE + 'Conflict.Attack_Attacker')
Conflict_Attack_BiologicalChemicalPoisonAttack_Attacker = URIRef(NAMESPACE + 'Conflict.Attack.BiologicalChemicalPoisonAttack_Attacker')
Conflict_Attack_BiologicalChemicalPoisonAttack_Instrument = URIRef(NAMESPACE + 'Conflict.Attack.BiologicalChemicalPoisonAttack_Instrument')
Conflict_Attack_BiologicalChemicalPoisonAttack_Place = URIRef(NAMESPACE + 'Conflict.Attack.BiologicalChemicalPoisonAttack_Place')
Conflict_Attack_BiologicalChemicalPoisonAttack_Target = URIRef(NAMESPACE + 'Conflict.Attack.BiologicalChemicalPoisonAttack_Target')
Conflict_Attack_Bombing_Attacker = URIRef(NAMESPACE + 'Conflict.Attack.Bombing_Attacker')
Conflict_Attack_Bombing_Instrument = URIRef(NAMESPACE + 'Conflict.Attack.Bombing_Instrument')
Conflict_Attack_Bombing_Place = URIRef(NAMESPACE + 'Conflict.Attack.Bombing_Place')
Conflict_Attack_Bombing_Target = URIRef(NAMESPACE + 'Conflict.Attack.Bombing_Target')
Conflict_Attack_FirearmAttack_Attacker = URIRef(NAMESPACE + 'Conflict.Attack.FirearmAttack_Attacker')
Conflict_Attack_FirearmAttack_Instrument = URIRef(NAMESPACE + 'Conflict.Attack.FirearmAttack_Instrument')
Conflict_Attack_FirearmAttack_Place = URIRef(NAMESPACE + 'Conflict.Attack.FirearmAttack_Place')
Conflict_Attack_FirearmAttack_Target = URIRef(NAMESPACE + 'Conflict.Attack.FirearmAttack_Target')
Conflict_Attack_Hanging_Attacker = URIRef(NAMESPACE + 'Conflict.Attack.Hanging_Attacker')
Conflict_Attack_Hanging_Instrument = URIRef(NAMESPACE + 'Conflict.Attack.Hanging_Instrument')
Conflict_Attack_Hanging_Place = URIRef(NAMESPACE + 'Conflict.Attack.Hanging_Place')
Conflict_Attack_Hanging_Target = URIRef(NAMESPACE + 'Conflict.Attack.Hanging_Target')
Conflict_Attack_Instrument = URIRef(NAMESPACE + 'Conflict.Attack_Instrument')
Conflict_Attack_Invade_Attacker = URIRef(NAMESPACE + 'Conflict.Attack.Invade_Attacker')
Conflict_Attack_Invade_Instrument = URIRef(NAMESPACE + 'Conflict.Attack.Invade_Instrument')
Conflict_Attack_Invade_Place = URIRef(NAMESPACE + 'Conflict.Attack.Invade_Place')
Conflict_Attack_Invade_Target = URIRef(NAMESPACE + 'Conflict.Attack.Invade_Target')
Conflict_Attack_Place = URIRef(NAMESPACE + 'Conflict.Attack_Place')
Conflict_Attack_SelfDirectedBattle_Attacker = URIRef(NAMESPACE + 'Conflict.Attack.SelfDirectedBattle_Attacker')
Conflict_Attack_SelfDirectedBattle_Instrument = URIRef(NAMESPACE + 'Conflict.Attack.SelfDirectedBattle_Instrument')
Conflict_Attack_SelfDirectedBattle_Place = URIRef(NAMESPACE + 'Conflict.Attack.SelfDirectedBattle_Place')
Conflict_Attack_SelfDirectedBattle_Target = URIRef(NAMESPACE + 'Conflict.Attack.SelfDirectedBattle_Target')
Conflict_Attack_SetFire_Attacker = URIRef(NAMESPACE + 'Conflict.Attack.SetFire_Attacker')
Conflict_Attack_SetFire_Instrument = URIRef(NAMESPACE + 'Conflict.Attack.SetFire_Instrument')
Conflict_Attack_SetFire_Place = URIRef(NAMESPACE + 'Conflict.Attack.SetFire_Place')
Conflict_Attack_SetFire_Target = URIRef(NAMESPACE + 'Conflict.Attack.SetFire_Target')
Conflict_Attack_Stabbing_Attacker = URIRef(NAMESPACE + 'Conflict.Attack.Stabbing_Attacker')
Conflict_Attack_Stabbing_Instrument = URIRef(NAMESPACE + 'Conflict.Attack.Stabbing_Instrument')
Conflict_Attack_Stabbing_Place = URIRef(NAMESPACE + 'Conflict.Attack.Stabbing_Place')
Conflict_Attack_Stabbing_Target = URIRef(NAMESPACE + 'Conflict.Attack.Stabbing_Target')
Conflict_Attack_StealRobHijack_Artifact = URIRef(NAMESPACE + 'Conflict.Attack.StealRobHijack_Artifact')
Conflict_Attack_StealRobHijack_Attacker = URIRef(NAMESPACE + 'Conflict.Attack.StealRobHijack_Attacker')
Conflict_Attack_StealRobHijack_Instrument = URIRef(NAMESPACE + 'Conflict.Attack.StealRobHijack_Instrument')
Conflict_Attack_StealRobHijack_Place = URIRef(NAMESPACE + 'Conflict.Attack.StealRobHijack_Place')
Conflict_Attack_StealRobHijack_Target = URIRef(NAMESPACE + 'Conflict.Attack.StealRobHijack_Target')
Conflict_Attack_Strangling_Attacker = URIRef(NAMESPACE + 'Conflict.Attack.Strangling_Attacker')
Conflict_Attack_Strangling_Instrument = URIRef(NAMESPACE + 'Conflict.Attack.Strangling_Instrument')
Conflict_Attack_Strangling_Place = URIRef(NAMESPACE + 'Conflict.Attack.Strangling_Place')
Conflict_Attack_Strangling_Target = URIRef(NAMESPACE + 'Conflict.Attack.Strangling_Target')
Conflict_Attack_Target = URIRef(NAMESPACE + 'Conflict.Attack_Target')
Conflict_Demonstrate_Demonstrator = URIRef(NAMESPACE + 'Conflict.Demonstrate_Demonstrator')
Conflict_Demonstrate_MarchProtestPoliticalGathering_Demonstrator = URIRef(NAMESPACE + 'Conflict.Demonstrate.MarchProtestPoliticalGathering_Demonstrator')
Conflict_Demonstrate_MarchProtestPoliticalGathering_Place = URIRef(NAMESPACE + 'Conflict.Demonstrate.MarchProtestPoliticalGathering_Place')
Conflict_Demonstrate_Place = URIRef(NAMESPACE + 'Conflict.Demonstrate_Place')
Conflict_Yield_Place = URIRef(NAMESPACE + 'Conflict.Yield_Place')
Conflict_Yield_Recipient = URIRef(NAMESPACE + 'Conflict.Yield_Recipient')
Conflict_Yield_Retreat_Destination = URIRef(NAMESPACE + 'Conflict.Yield.Retreat_Destination')
Conflict_Yield_Retreat_Origin = URIRef(NAMESPACE + 'Conflict.Yield.Retreat_Origin')
Conflict_Yield_Retreat_Retreater = URIRef(NAMESPACE + 'Conflict.Yield.Retreat_Retreater')
Conflict_Yield_Surrender_Place = URIRef(NAMESPACE + 'Conflict.Yield.Surrender_Place')
Conflict_Yield_Surrender_Recipient = URIRef(NAMESPACE + 'Conflict.Yield.Surrender_Recipient')
Conflict_Yield_Surrender_Surrenderer = URIRef(NAMESPACE + 'Conflict.Yield.Surrender_Surrenderer')
Conflict_Yield_Yielder = URIRef(NAMESPACE + 'Conflict.Yield_Yielder')
Contact_Collaborate_Correspondence_Participant = URIRef(NAMESPACE + 'Contact.Collaborate.Correspondence_Participant')
Contact_Collaborate_Correspondence_Place = URIRef(NAMESPACE + 'Contact.Collaborate.Correspondence_Place')
Contact_Collaborate_Meet_Participant = URIRef(NAMESPACE + 'Contact.Collaborate.Meet_Participant')
Contact_Collaborate_Meet_Place = URIRef(NAMESPACE + 'Contact.Collaborate.Meet_Place')
Contact_Collaborate_Participant = URIRef(NAMESPACE + 'Contact.Collaborate_Participant')
Contact_Collaborate_Place = URIRef(NAMESPACE + 'Contact.Collaborate_Place')
Contact_CommandOrder_Broadcast_Communicator = URIRef(NAMESPACE + 'Contact.CommandOrder.Broadcast_Communicator')
Contact_CommandOrder_Broadcast_Place = URIRef(NAMESPACE + 'Contact.CommandOrder.Broadcast_Place')
Contact_CommandOrder_Broadcast_Recipient = URIRef(NAMESPACE + 'Contact.CommandOrder.Broadcast_Recipient')
Contact_CommandOrder_Communicator = URIRef(NAMESPACE + 'Contact.CommandOrder_Communicator')
Contact_CommandOrder_Correspondence_Communicator = URIRef(NAMESPACE + 'Contact.CommandOrder.Correspondence_Communicator')
Contact_CommandOrder_Correspondence_Place = URIRef(NAMESPACE + 'Contact.CommandOrder.Correspondence_Place')
Contact_CommandOrder_Correspondence_Recipient = URIRef(NAMESPACE + 'Contact.CommandOrder.Correspondence_Recipient')
Contact_CommandOrder_Meet_Communicator = URIRef(NAMESPACE + 'Contact.CommandOrder.Meet_Communicator')
Contact_CommandOrder_Meet_Place = URIRef(NAMESPACE + 'Contact.CommandOrder.Meet_Place')
Contact_CommandOrder_Meet_Recipient = URIRef(NAMESPACE + 'Contact.CommandOrder.Meet_Recipient')
Contact_CommandOrder_Place = URIRef(NAMESPACE + 'Contact.CommandOrder_Place')
Contact_CommandOrder_Recipient = URIRef(NAMESPACE + 'Contact.CommandOrder_Recipient')
Contact_CommitmentPromiseExpressIntent_Broadcast_Communicator = URIRef(NAMESPACE + 'Contact.CommitmentPromiseExpressIntent.Broadcast_Communicator')
Contact_CommitmentPromiseExpressIntent_Broadcast_Place = URIRef(NAMESPACE + 'Contact.CommitmentPromiseExpressIntent.Broadcast_Place')
Contact_CommitmentPromiseExpressIntent_Broadcast_Recipient = URIRef(NAMESPACE + 'Contact.CommitmentPromiseExpressIntent.Broadcast_Recipient')
Contact_CommitmentPromiseExpressIntent_Communicator = URIRef(NAMESPACE + 'Contact.CommitmentPromiseExpressIntent_Communicator')
Contact_CommitmentPromiseExpressIntent_Correspondence_Communicator = URIRef(NAMESPACE + 'Contact.CommitmentPromiseExpressIntent.Correspondence_Communicator')
Contact_CommitmentPromiseExpressIntent_Correspondence_Place = URIRef(NAMESPACE + 'Contact.CommitmentPromiseExpressIntent.Correspondence_Place')
Contact_CommitmentPromiseExpressIntent_Correspondence_Recipient = URIRef(NAMESPACE + 'Contact.CommitmentPromiseExpressIntent.Correspondence_Recipient')
Contact_CommitmentPromiseExpressIntent_Meet_Communicator = URIRef(NAMESPACE + 'Contact.CommitmentPromiseExpressIntent.Meet_Communicator')
Contact_CommitmentPromiseExpressIntent_Meet_Place = URIRef(NAMESPACE + 'Contact.CommitmentPromiseExpressIntent.Meet_Place')
Contact_CommitmentPromiseExpressIntent_Meet_Recipient = URIRef(NAMESPACE + 'Contact.CommitmentPromiseExpressIntent.Meet_Recipient')
Contact_CommitmentPromiseExpressIntent_Place = URIRef(NAMESPACE + 'Contact.CommitmentPromiseExpressIntent_Place')
Contact_CommitmentPromiseExpressIntent_Recipient = URIRef(NAMESPACE + 'Contact.CommitmentPromiseExpressIntent_Recipient')
Contact_Discussion_Correspondence_Participant = URIRef(NAMESPACE + 'Contact.Discussion.Correspondence_Participant')
Contact_Discussion_Correspondence_Place = URIRef(NAMESPACE + 'Contact.Discussion.Correspondence_Place')
Contact_Discussion_Meet_Participant = URIRef(NAMESPACE + 'Contact.Discussion.Meet_Participant')
Contact_Discussion_Meet_Place = URIRef(NAMESPACE + 'Contact.Discussion.Meet_Place')
Contact_Discussion_Participant = URIRef(NAMESPACE + 'Contact.Discussion_Participant')
Contact_Discussion_Place = URIRef(NAMESPACE + 'Contact.Discussion_Place')
Contact_FuneralVigil_Deceased = URIRef(NAMESPACE + 'Contact.FuneralVigil_Deceased')
Contact_FuneralVigil_Meet_Deceased = URIRef(NAMESPACE + 'Contact.FuneralVigil.Meet_Deceased')
Contact_FuneralVigil_Meet_Participant = URIRef(NAMESPACE + 'Contact.FuneralVigil.Meet_Participant')
Contact_FuneralVigil_Meet_Place = URIRef(NAMESPACE + 'Contact.FuneralVigil.Meet_Place')
Contact_FuneralVigil_Participant = URIRef(NAMESPACE + 'Contact.FuneralVigil_Participant')
Contact_FuneralVigil_Place = URIRef(NAMESPACE + 'Contact.FuneralVigil_Place')
Contact_MediaStatement_Broadcast_Communicator = URIRef(NAMESPACE + 'Contact.MediaStatement.Broadcast_Communicator')
Contact_MediaStatement_Broadcast_Place = URIRef(NAMESPACE + 'Contact.MediaStatement.Broadcast_Place')
Contact_MediaStatement_Broadcast_Recipient = URIRef(NAMESPACE + 'Contact.MediaStatement.Broadcast_Recipient')
Contact_MediaStatement_Communicator = URIRef(NAMESPACE + 'Contact.MediaStatement_Communicator')
Contact_MediaStatement_Place = URIRef(NAMESPACE + 'Contact.MediaStatement_Place')
Contact_MediaStatement_Recipient = URIRef(NAMESPACE + 'Contact.MediaStatement_Recipient')
Contact_Negotiate_Correspondence_Participant = URIRef(NAMESPACE + 'Contact.Negotiate.Correspondence_Participant')
Contact_Negotiate_Correspondence_Place = URIRef(NAMESPACE + 'Contact.Negotiate.Correspondence_Place')
Contact_Negotiate_Meet_Participant = URIRef(NAMESPACE + 'Contact.Negotiate.Meet_Participant')
Contact_Negotiate_Meet_Place = URIRef(NAMESPACE + 'Contact.Negotiate.Meet_Place')
Contact_Negotiate_Participant = URIRef(NAMESPACE + 'Contact.Negotiate_Participant')
Contact_Negotiate_Place = URIRef(NAMESPACE + 'Contact.Negotiate_Place')
Contact_Prevarication_Broadcast_Communicator = URIRef(NAMESPACE + 'Contact.Prevarication.Broadcast_Communicator')
Contact_Prevarication_Broadcast_Place = URIRef(NAMESPACE + 'Contact.Prevarication.Broadcast_Place')
Contact_Prevarication_Broadcast_Recipient = URIRef(NAMESPACE + 'Contact.Prevarication.Broadcast_Recipient')
Contact_Prevarication_Communicator = URIRef(NAMESPACE + 'Contact.Prevarication_Communicator')
Contact_Prevarication_Correspondence_Communicator = URIRef(NAMESPACE + 'Contact.Prevarication.Correspondence_Communicator')
Contact_Prevarication_Correspondence_Place = URIRef(NAMESPACE + 'Contact.Prevarication.Correspondence_Place')
Contact_Prevarication_Correspondence_Recipient = URIRef(NAMESPACE + 'Contact.Prevarication.Correspondence_Recipient')
Contact_Prevarication_Meet_Communicator = URIRef(NAMESPACE + 'Contact.Prevarication.Meet_Communicator')
Contact_Prevarication_Meet_Place = URIRef(NAMESPACE + 'Contact.Prevarication.Meet_Place')
Contact_Prevarication_Meet_Recipient = URIRef(NAMESPACE + 'Contact.Prevarication.Meet_Recipient')
Contact_Prevarication_Place = URIRef(NAMESPACE + 'Contact.Prevarication_Place')
Contact_Prevarication_Recipient = URIRef(NAMESPACE + 'Contact.Prevarication_Recipient')
Contact_PublicStatementInPerson_Broadcast_Communicator = URIRef(NAMESPACE + 'Contact.PublicStatementInPerson.Broadcast_Communicator')
Contact_PublicStatementInPerson_Broadcast_Place = URIRef(NAMESPACE + 'Contact.PublicStatementInPerson.Broadcast_Place')
Contact_PublicStatementInPerson_Broadcast_Recipient = URIRef(NAMESPACE + 'Contact.PublicStatementInPerson.Broadcast_Recipient')
Contact_PublicStatementInPerson_Communicator = URIRef(NAMESPACE + 'Contact.PublicStatementInPerson_Communicator')
Contact_PublicStatementInPerson_Place = URIRef(NAMESPACE + 'Contact.PublicStatementInPerson_Place')
Contact_PublicStatementInPerson_Recipient = URIRef(NAMESPACE + 'Contact.PublicStatementInPerson_Recipient')
Contact_RequestAdvise_Broadcast_Communicator = URIRef(NAMESPACE + 'Contact.RequestAdvise.Broadcast_Communicator')
Contact_RequestAdvise_Broadcast_Place = URIRef(NAMESPACE + 'Contact.RequestAdvise.Broadcast_Place')
Contact_RequestAdvise_Broadcast_Recipient = URIRef(NAMESPACE + 'Contact.RequestAdvise.Broadcast_Recipient')
Contact_RequestAdvise_Communicator = URIRef(NAMESPACE + 'Contact.RequestAdvise_Communicator')
Contact_RequestAdvise_Correspondence_Communicator = URIRef(NAMESPACE + 'Contact.RequestAdvise.Correspondence_Communicator')
Contact_RequestAdvise_Correspondence_Place = URIRef(NAMESPACE + 'Contact.RequestAdvise.Correspondence_Place')
Contact_RequestAdvise_Correspondence_Recipient = URIRef(NAMESPACE + 'Contact.RequestAdvise.Correspondence_Recipient')
Contact_RequestAdvise_Meet_Communicator = URIRef(NAMESPACE + 'Contact.RequestAdvise.Meet_Communicator')
Contact_RequestAdvise_Meet_Place = URIRef(NAMESPACE + 'Contact.RequestAdvise.Meet_Place')
Contact_RequestAdvise_Meet_Recipient = URIRef(NAMESPACE + 'Contact.RequestAdvise.Meet_Recipient')
Contact_RequestAdvise_Place = URIRef(NAMESPACE + 'Contact.RequestAdvise_Place')
Contact_RequestAdvise_Recipient = URIRef(NAMESPACE + 'Contact.RequestAdvise_Recipient')
Contact_ThreatenCoerce_Broadcast_Communicator = URIRef(NAMESPACE + 'Contact.ThreatenCoerce.Broadcast_Communicator')
Contact_ThreatenCoerce_Broadcast_Place = URIRef(NAMESPACE + 'Contact.ThreatenCoerce.Broadcast_Place')
Contact_ThreatenCoerce_Broadcast_Recipient = URIRef(NAMESPACE + 'Contact.ThreatenCoerce.Broadcast_Recipient')
Contact_ThreatenCoerce_Communicator = URIRef(NAMESPACE + 'Contact.ThreatenCoerce_Communicator')
Contact_ThreatenCoerce_Correspondence_Communicator = URIRef(NAMESPACE + 'Contact.ThreatenCoerce.Correspondence_Communicator')
Contact_ThreatenCoerce_Correspondence_Place = URIRef(NAMESPACE + 'Contact.ThreatenCoerce.Correspondence_Place')
Contact_ThreatenCoerce_Correspondence_Recipient = URIRef(NAMESPACE + 'Contact.ThreatenCoerce.Correspondence_Recipient')
Contact_ThreatenCoerce_Meet_Communicator = URIRef(NAMESPACE + 'Contact.ThreatenCoerce.Meet_Communicator')
Contact_ThreatenCoerce_Meet_Place = URIRef(NAMESPACE + 'Contact.ThreatenCoerce.Meet_Place')
Contact_ThreatenCoerce_Meet_Recipient = URIRef(NAMESPACE + 'Contact.ThreatenCoerce.Meet_Recipient')
Contact_ThreatenCoerce_Place = URIRef(NAMESPACE + 'Contact.ThreatenCoerce_Place')
Contact_ThreatenCoerce_Recipient = URIRef(NAMESPACE + 'Contact.ThreatenCoerce_Recipient')
Disaster_AccidentCrash_AccidentCrash_CrashObject = URIRef(NAMESPACE + 'Disaster.AccidentCrash.AccidentCrash_CrashObject')
Disaster_AccidentCrash_AccidentCrash_DriverPassenger = URIRef(NAMESPACE + 'Disaster.AccidentCrash.AccidentCrash_DriverPassenger')
Disaster_AccidentCrash_AccidentCrash_Place = URIRef(NAMESPACE + 'Disaster.AccidentCrash.AccidentCrash_Place')
Disaster_AccidentCrash_AccidentCrash_Vehicle = URIRef(NAMESPACE + 'Disaster.AccidentCrash.AccidentCrash_Vehicle')
Disaster_FireExplosion_FireExplosion_FireExplosionObject = URIRef(NAMESPACE + 'Disaster.FireExplosion.FireExplosion_FireExplosionObject')
Disaster_FireExplosion_FireExplosion_Instrument = URIRef(NAMESPACE + 'Disaster.FireExplosion.FireExplosion_Instrument')
Disaster_FireExplosion_FireExplosion_Place = URIRef(NAMESPACE + 'Disaster.FireExplosion.FireExplosion_Place')
Evaluate_Deliberateness_Accidental_Event = URIRef(NAMESPACE + 'Evaluate.Deliberateness.Accidental_Event')
Evaluate_Deliberateness_Accidental_Holder = URIRef(NAMESPACE + 'Evaluate.Deliberateness.Accidental_Holder')
Evaluate_Deliberateness_Deliberate_Event = URIRef(NAMESPACE + 'Evaluate.Deliberateness.Deliberate_Event')
Evaluate_Deliberateness_Deliberate_Holder = URIRef(NAMESPACE + 'Evaluate.Deliberateness.Deliberate_Holder')
Evaluate_Legitimacy_Illegitimate_Event = URIRef(NAMESPACE + 'Evaluate.Legitimacy.Illegitimate_Event')
Evaluate_Legitimacy_Illegitimate_Holder = URIRef(NAMESPACE + 'Evaluate.Legitimacy.Illegitimate_Holder')
Evaluate_Legitimacy_Legitimate_Event = URIRef(NAMESPACE + 'Evaluate.Legitimacy.Legitimate_Event')
Evaluate_Legitimacy_Legitimate_Holder = URIRef(NAMESPACE + 'Evaluate.Legitimacy.Legitimate_Holder')
Evaluate_Sentiment_Negative_Holder = URIRef(NAMESPACE + 'Evaluate.Sentiment.Negative_Holder')
Evaluate_Sentiment_Negative_SentimentTarget = URIRef(NAMESPACE + 'Evaluate.Sentiment.Negative_SentimentTarget')
Evaluate_Sentiment_Positive_Holder = URIRef(NAMESPACE + 'Evaluate.Sentiment.Positive_Holder')
Evaluate_Sentiment_Positive_SentimentTarget = URIRef(NAMESPACE + 'Evaluate.Sentiment.Positive_SentimentTarget')
GeneralAffiliation_ArtifactPoliticalOrganizationReligiousAffiliation_Artifact = URIRef(NAMESPACE + 'GeneralAffiliation.ArtifactPoliticalOrganizationReligiousAffiliation_Artifact')
GeneralAffiliation_ArtifactPoliticalOrganizationReligiousAffiliation_ControlTerritory_Controller = URIRef(NAMESPACE + 'GeneralAffiliation.ArtifactPoliticalOrganizationReligiousAffiliation.ControlTerritory_Controller')
GeneralAffiliation_ArtifactPoliticalOrganizationReligiousAffiliation_ControlTerritory_Territory = URIRef(NAMESPACE + 'GeneralAffiliation.ArtifactPoliticalOrganizationReligiousAffiliation.ControlTerritory_Territory')
GeneralAffiliation_ArtifactPoliticalOrganizationReligiousAffiliation_EntityOrFiller = URIRef(NAMESPACE + 'GeneralAffiliation.ArtifactPoliticalOrganizationReligiousAffiliation_EntityOrFiller')
GeneralAffiliation_ArtifactPoliticalOrganizationReligiousAffiliation_NationalityCitizen_Artifact = URIRef(NAMESPACE + 'GeneralAffiliation.ArtifactPoliticalOrganizationReligiousAffiliation.NationalityCitizen_Artifact')
GeneralAffiliation_ArtifactPoliticalOrganizationReligiousAffiliation_NationalityCitizen_Nationality = URIRef(NAMESPACE + 'GeneralAffiliation.ArtifactPoliticalOrganizationReligiousAffiliation.NationalityCitizen_Nationality')
GeneralAffiliation_ArtifactPoliticalOrganizationReligiousAffiliation_OwnershipPossession_Artifact = URIRef(NAMESPACE + 'GeneralAffiliation.ArtifactPoliticalOrganizationReligiousAffiliation.OwnershipPossession_Artifact')
GeneralAffiliation_ArtifactPoliticalOrganizationReligiousAffiliation_OwnershipPossession_Owner = URIRef(NAMESPACE + 'GeneralAffiliation.ArtifactPoliticalOrganizationReligiousAffiliation.OwnershipPossession_Owner')
GeneralAffiliation_MemberOriginReligionEthnicity_EntityOrFiller = URIRef(NAMESPACE + 'GeneralAffiliation.MemberOriginReligionEthnicity_EntityOrFiller')
GeneralAffiliation_MemberOriginReligionEthnicity_Ethnicity_Ethnicity = URIRef(NAMESPACE + 'GeneralAffiliation.MemberOriginReligionEthnicity.Ethnicity_Ethnicity')
GeneralAffiliation_MemberOriginReligionEthnicity_Ethnicity_Person = URIRef(NAMESPACE + 'GeneralAffiliation.MemberOriginReligionEthnicity.Ethnicity_Person')
GeneralAffiliation_MemberOriginReligionEthnicity_NationalityCitizen_Citizen = URIRef(NAMESPACE + 'GeneralAffiliation.MemberOriginReligionEthnicity.NationalityCitizen_Citizen')
GeneralAffiliation_MemberOriginReligionEthnicity_NationalityCitizen_Nationality = URIRef(NAMESPACE + 'GeneralAffiliation.MemberOriginReligionEthnicity.NationalityCitizen_Nationality')
GeneralAffiliation_MemberOriginReligionEthnicity_Person = URIRef(NAMESPACE + 'GeneralAffiliation.MemberOriginReligionEthnicity_Person')
GeneralAffiliation_OrganizationPoliticalReligiousAffiliation_EntityOrFiller = URIRef(NAMESPACE + 'GeneralAffiliation.OrganizationPoliticalReligiousAffiliation_EntityOrFiller')
GeneralAffiliation_OrganizationPoliticalReligiousAffiliation_NationalityCitizen_Nationality = URIRef(NAMESPACE + 'GeneralAffiliation.OrganizationPoliticalReligiousAffiliation.NationalityCitizen_Nationality')
GeneralAffiliation_OrganizationPoliticalReligiousAffiliation_NationalityCitizen_Organization = URIRef(NAMESPACE + 'GeneralAffiliation.OrganizationPoliticalReligiousAffiliation.NationalityCitizen_Organization')
GeneralAffiliation_OrganizationPoliticalReligiousAffiliation_Organization = URIRef(NAMESPACE + 'GeneralAffiliation.OrganizationPoliticalReligiousAffiliation_Organization')
GeneralAffiliation_OrganizationWebsite_OrganizationWebsite_Organization = URIRef(NAMESPACE + 'GeneralAffiliation.OrganizationWebsite.OrganizationWebsite_Organization')
GeneralAffiliation_OrganizationWebsite_OrganizationWebsite_Website = URIRef(NAMESPACE + 'GeneralAffiliation.OrganizationWebsite.OrganizationWebsite_Website')
GeneralAffiliation_Sponsorship_ActorOrEvent = URIRef(NAMESPACE + 'GeneralAffiliation.Sponsorship_ActorOrEvent')
GeneralAffiliation_Sponsorship_AdvisePlanOrganize_ActorOrEvent = URIRef(NAMESPACE + 'GeneralAffiliation.Sponsorship.AdvisePlanOrganize_ActorOrEvent')
GeneralAffiliation_Sponsorship_AdvisePlanOrganize_Sponsor = URIRef(NAMESPACE + 'GeneralAffiliation.Sponsorship.AdvisePlanOrganize_Sponsor')
GeneralAffiliation_Sponsorship_Affiliated_ActorOrEvent = URIRef(NAMESPACE + 'GeneralAffiliation.Sponsorship.Affiliated_ActorOrEvent')
GeneralAffiliation_Sponsorship_Affiliated_Sponsor = URIRef(NAMESPACE + 'GeneralAffiliation.Sponsorship.Affiliated_Sponsor')
GeneralAffiliation_Sponsorship_HelpSupport_ActorOrEvent = URIRef(NAMESPACE + 'GeneralAffiliation.Sponsorship.HelpSupport_ActorOrEvent')
GeneralAffiliation_Sponsorship_HelpSupport_Sponsor = URIRef(NAMESPACE + 'GeneralAffiliation.Sponsorship.HelpSupport_Sponsor')
GeneralAffiliation_Sponsorship_Sponsor = URIRef(NAMESPACE + 'GeneralAffiliation.Sponsorship_Sponsor')
Government_Agreements_AcceptAgreementContractCeasefire_Participant = URIRef(NAMESPACE + 'Government.Agreements.AcceptAgreementContractCeasefire_Participant')
Government_Agreements_AcceptAgreementContractCeasefire_Place = URIRef(NAMESPACE + 'Government.Agreements.AcceptAgreementContractCeasefire_Place')
Government_Agreements_Participant = URIRef(NAMESPACE + 'Government.Agreements_Participant')
Government_Agreements_Place = URIRef(NAMESPACE + 'Government.Agreements_Place')
Government_Agreements_RejectNullifyAgreementContractCeasefire_OtherParticipant = URIRef(NAMESPACE + 'Government.Agreements.RejectNullifyAgreementContractCeasefire_OtherParticipant')
Government_Agreements_RejectNullifyAgreementContractCeasefire_Place = URIRef(NAMESPACE + 'Government.Agreements.RejectNullifyAgreementContractCeasefire_Place')
Government_Agreements_RejectNullifyAgreementContractCeasefire_RejecterNullifier = URIRef(NAMESPACE + 'Government.Agreements.RejectNullifyAgreementContractCeasefire_RejecterNullifier')
Government_Agreements_ViolateAgreement_OtherParticipant = URIRef(NAMESPACE + 'Government.Agreements.ViolateAgreement_OtherParticipant')
Government_Agreements_ViolateAgreement_Place = URIRef(NAMESPACE + 'Government.Agreements.ViolateAgreement_Place')
Government_Agreements_ViolateAgreement_Violator = URIRef(NAMESPACE + 'Government.Agreements.ViolateAgreement_Violator')
Government_Formation_Founder = URIRef(NAMESPACE + 'Government.Formation_Founder')
Government_Formation_GPE = URIRef(NAMESPACE + 'Government.Formation_GPE')
Government_Formation_MergeGPE_Participant = URIRef(NAMESPACE + 'Government.Formation.MergeGPE_Participant')
Government_Formation_MergeGPE_Place = URIRef(NAMESPACE + 'Government.Formation.MergeGPE_Place')
Government_Formation_Place = URIRef(NAMESPACE + 'Government.Formation_Place')
Government_Formation_StartGPE_Founder = URIRef(NAMESPACE + 'Government.Formation.StartGPE_Founder')
Government_Formation_StartGPE_GPE = URIRef(NAMESPACE + 'Government.Formation.StartGPE_GPE')
Government_Formation_StartGPE_Place = URIRef(NAMESPACE + 'Government.Formation.StartGPE_Place')
Government_Legislate_Legislate_GovernmentBody = URIRef(NAMESPACE + 'Government.Legislate.Legislate_GovernmentBody')
Government_Legislate_Legislate_Law = URIRef(NAMESPACE + 'Government.Legislate.Legislate_Law')
Government_Legislate_Legislate_Place = URIRef(NAMESPACE + 'Government.Legislate.Legislate_Place')
Government_Spy_Spy_Beneficiary = URIRef(NAMESPACE + 'Government.Spy.Spy_Beneficiary')
Government_Spy_Spy_ObservedEntity = URIRef(NAMESPACE + 'Government.Spy.Spy_ObservedEntity')
Government_Spy_Spy_Place = URIRef(NAMESPACE + 'Government.Spy.Spy_Place')
Government_Spy_Spy_Spy = URIRef(NAMESPACE + 'Government.Spy.Spy_Spy')
Government_Vote_Ballot = URIRef(NAMESPACE + 'Government.Vote_Ballot')
Government_Vote_Candidate = URIRef(NAMESPACE + 'Government.Vote_Candidate')
Government_Vote_CastVote_Ballot = URIRef(NAMESPACE + 'Government.Vote.CastVote_Ballot')
Government_Vote_CastVote_Candidate = URIRef(NAMESPACE + 'Government.Vote.CastVote_Candidate')
Government_Vote_CastVote_Place = URIRef(NAMESPACE + 'Government.Vote.CastVote_Place')
Government_Vote_CastVote_Result = URIRef(NAMESPACE + 'Government.Vote.CastVote_Result')
Government_Vote_CastVote_Voter = URIRef(NAMESPACE + 'Government.Vote.CastVote_Voter')
Government_Vote_Place = URIRef(NAMESPACE + 'Government.Vote_Place')
Government_Vote_Result = URIRef(NAMESPACE + 'Government.Vote_Result')
Government_Vote_ViolationsPreventVote_Ballot = URIRef(NAMESPACE + 'Government.Vote.ViolationsPreventVote_Ballot')
Government_Vote_ViolationsPreventVote_Candidate = URIRef(NAMESPACE + 'Government.Vote.ViolationsPreventVote_Candidate')
Government_Vote_ViolationsPreventVote_Place = URIRef(NAMESPACE + 'Government.Vote.ViolationsPreventVote_Place')
Government_Vote_ViolationsPreventVote_Preventer = URIRef(NAMESPACE + 'Government.Vote.ViolationsPreventVote_Preventer')
Government_Vote_ViolationsPreventVote_Voter = URIRef(NAMESPACE + 'Government.Vote.ViolationsPreventVote_Voter')
Government_Vote_Voter = URIRef(NAMESPACE + 'Government.Vote_Voter')
Information_Color_Color_Color = URIRef(NAMESPACE + 'Information.Color.Color_Color')
Information_Color_Color_EntityOrFiller = URIRef(NAMESPACE + 'Information.Color.Color_EntityOrFiller')
Information_Make_Make_Brand = URIRef(NAMESPACE + 'Information.Make.Make_Brand')
Information_Make_Make_EntityOrFiller = URIRef(NAMESPACE + 'Information.Make.Make_EntityOrFiller')
Inspection_SensoryObserve_InspectPeopleOrganization_InspectedEntity = URIRef(NAMESPACE + 'Inspection.SensoryObserve.InspectPeopleOrganization_InspectedEntity')
Inspection_SensoryObserve_InspectPeopleOrganization_Inspector = URIRef(NAMESPACE + 'Inspection.SensoryObserve.InspectPeopleOrganization_Inspector')
Inspection_SensoryObserve_InspectPeopleOrganization_Place = URIRef(NAMESPACE + 'Inspection.SensoryObserve.InspectPeopleOrganization_Place')
Inspection_SensoryObserve_MonitorElection_Monitor = URIRef(NAMESPACE + 'Inspection.SensoryObserve.MonitorElection_Monitor')
Inspection_SensoryObserve_MonitorElection_MonitoredEntity = URIRef(NAMESPACE + 'Inspection.SensoryObserve.MonitorElection_MonitoredEntity')
Inspection_SensoryObserve_MonitorElection_Place = URIRef(NAMESPACE + 'Inspection.SensoryObserve.MonitorElection_Place')
Inspection_SensoryObserve_ObservedEntity = URIRef(NAMESPACE + 'Inspection.SensoryObserve_ObservedEntity')
Inspection_SensoryObserve_Observer = URIRef(NAMESPACE + 'Inspection.SensoryObserve_Observer')
Inspection_SensoryObserve_PhysicalInvestigateInspect_InspectedEntity = URIRef(NAMESPACE + 'Inspection.SensoryObserve.PhysicalInvestigateInspect_InspectedEntity')
Inspection_SensoryObserve_PhysicalInvestigateInspect_Inspector = URIRef(NAMESPACE + 'Inspection.SensoryObserve.PhysicalInvestigateInspect_Inspector')
Inspection_SensoryObserve_PhysicalInvestigateInspect_Place = URIRef(NAMESPACE + 'Inspection.SensoryObserve.PhysicalInvestigateInspect_Place')
Inspection_SensoryObserve_Place = URIRef(NAMESPACE + 'Inspection.SensoryObserve_Place')
Justice_ArrestJailDetain_ArrestJailDetain_Crime = URIRef(NAMESPACE + 'Justice.ArrestJailDetain.ArrestJailDetain_Crime')
Justice_ArrestJailDetain_ArrestJailDetain_Detainee = URIRef(NAMESPACE + 'Justice.ArrestJailDetain.ArrestJailDetain_Detainee')
Justice_ArrestJailDetain_ArrestJailDetain_Jailer = URIRef(NAMESPACE + 'Justice.ArrestJailDetain.ArrestJailDetain_Jailer')
Justice_ArrestJailDetain_ArrestJailDetain_Place = URIRef(NAMESPACE + 'Justice.ArrestJailDetain.ArrestJailDetain_Place')
Justice_InitiateJudicialProcess_ChargeIndict_Crime = URIRef(NAMESPACE + 'Justice.InitiateJudicialProcess.ChargeIndict_Crime')
Justice_InitiateJudicialProcess_ChargeIndict_Defendant = URIRef(NAMESPACE + 'Justice.InitiateJudicialProcess.ChargeIndict_Defendant')
Justice_InitiateJudicialProcess_ChargeIndict_JudgeCourt = URIRef(NAMESPACE + 'Justice.InitiateJudicialProcess.ChargeIndict_JudgeCourt')
Justice_InitiateJudicialProcess_ChargeIndict_Place = URIRef(NAMESPACE + 'Justice.InitiateJudicialProcess.ChargeIndict_Place')
Justice_InitiateJudicialProcess_ChargeIndict_Prosecutor = URIRef(NAMESPACE + 'Justice.InitiateJudicialProcess.ChargeIndict_Prosecutor')
Justice_InitiateJudicialProcess_Crime = URIRef(NAMESPACE + 'Justice.InitiateJudicialProcess_Crime')
Justice_InitiateJudicialProcess_Defendant = URIRef(NAMESPACE + 'Justice.InitiateJudicialProcess_Defendant')
Justice_InitiateJudicialProcess_JudgeCourt = URIRef(NAMESPACE + 'Justice.InitiateJudicialProcess_JudgeCourt')
Justice_InitiateJudicialProcess_Place = URIRef(NAMESPACE + 'Justice.InitiateJudicialProcess_Place')
Justice_InitiateJudicialProcess_Prosecutor = URIRef(NAMESPACE + 'Justice.InitiateJudicialProcess_Prosecutor')
Justice_InitiateJudicialProcess_TrialHearing_Crime = URIRef(NAMESPACE + 'Justice.InitiateJudicialProcess.TrialHearing_Crime')
Justice_InitiateJudicialProcess_TrialHearing_Defendant = URIRef(NAMESPACE + 'Justice.InitiateJudicialProcess.TrialHearing_Defendant')
Justice_InitiateJudicialProcess_TrialHearing_JudgeCourt = URIRef(NAMESPACE + 'Justice.InitiateJudicialProcess.TrialHearing_JudgeCourt')
Justice_InitiateJudicialProcess_TrialHearing_Place = URIRef(NAMESPACE + 'Justice.InitiateJudicialProcess.TrialHearing_Place')
Justice_InitiateJudicialProcess_TrialHearing_Prosecutor = URIRef(NAMESPACE + 'Justice.InitiateJudicialProcess.TrialHearing_Prosecutor')
Justice_Investigate_Defendant = URIRef(NAMESPACE + 'Justice.Investigate_Defendant')
Justice_Investigate_InvestigateCrime_Crime = URIRef(NAMESPACE + 'Justice.Investigate.InvestigateCrime_Crime')
Justice_Investigate_InvestigateCrime_Defendant = URIRef(NAMESPACE + 'Justice.Investigate.InvestigateCrime_Defendant')
Justice_Investigate_InvestigateCrime_Investigator = URIRef(NAMESPACE + 'Justice.Investigate.InvestigateCrime_Investigator')
Justice_Investigate_InvestigateCrime_Place = URIRef(NAMESPACE + 'Justice.Investigate.InvestigateCrime_Place')
Justice_Investigate_Investigator = URIRef(NAMESPACE + 'Justice.Investigate_Investigator')
Justice_Investigate_Place = URIRef(NAMESPACE + 'Justice.Investigate_Place')
Justice_JudicialConsequences_Convict_Crime = URIRef(NAMESPACE + 'Justice.JudicialConsequences.Convict_Crime')
Justice_JudicialConsequences_Convict_Defendant = URIRef(NAMESPACE + 'Justice.JudicialConsequences.Convict_Defendant')
Justice_JudicialConsequences_Convict_JudgeCourt = URIRef(NAMESPACE + 'Justice.JudicialConsequences.Convict_JudgeCourt')
Justice_JudicialConsequences_Convict_Place = URIRef(NAMESPACE + 'Justice.JudicialConsequences.Convict_Place')
Justice_JudicialConsequences_Crime = URIRef(NAMESPACE + 'Justice.JudicialConsequences_Crime')
Justice_JudicialConsequences_Defendant = URIRef(NAMESPACE + 'Justice.JudicialConsequences_Defendant')
Justice_JudicialConsequences_Execute_Crime = URIRef(NAMESPACE + 'Justice.JudicialConsequences.Execute_Crime')
Justice_JudicialConsequences_Execute_Defendant = URIRef(NAMESPACE + 'Justice.JudicialConsequences.Execute_Defendant')
Justice_JudicialConsequences_Execute_Executioner = URIRef(NAMESPACE + 'Justice.JudicialConsequences.Execute_Executioner')
Justice_JudicialConsequences_Execute_Place = URIRef(NAMESPACE + 'Justice.JudicialConsequences.Execute_Place')
Justice_JudicialConsequences_Extradite_Crime = URIRef(NAMESPACE + 'Justice.JudicialConsequences.Extradite_Crime')
Justice_JudicialConsequences_Extradite_Defendant = URIRef(NAMESPACE + 'Justice.JudicialConsequences.Extradite_Defendant')
Justice_JudicialConsequences_Extradite_Destination = URIRef(NAMESPACE + 'Justice.JudicialConsequences.Extradite_Destination')
Justice_JudicialConsequences_Extradite_Extraditer = URIRef(NAMESPACE + 'Justice.JudicialConsequences.Extradite_Extraditer')
Justice_JudicialConsequences_Extradite_Origin = URIRef(NAMESPACE + 'Justice.JudicialConsequences.Extradite_Origin')
Justice_JudicialConsequences_JudgeCourt = URIRef(NAMESPACE + 'Justice.JudicialConsequences_JudgeCourt')
Justice_JudicialConsequences_Place = URIRef(NAMESPACE + 'Justice.JudicialConsequences_Place')
Life_Die_DeathCausedByViolentEvents_Instrument = URIRef(NAMESPACE + 'Life.Die.DeathCausedByViolentEvents_Instrument')
Life_Die_DeathCausedByViolentEvents_Killer = URIRef(NAMESPACE + 'Life.Die.DeathCausedByViolentEvents_Killer')
Life_Die_DeathCausedByViolentEvents_Place = URIRef(NAMESPACE + 'Life.Die.DeathCausedByViolentEvents_Place')
Life_Die_DeathCausedByViolentEvents_Victim = URIRef(NAMESPACE + 'Life.Die.DeathCausedByViolentEvents_Victim')
Life_Die_NonviolentDeath_Place = URIRef(NAMESPACE + 'Life.Die.NonviolentDeath_Place')
Life_Die_NonviolentDeath_Victim = URIRef(NAMESPACE + 'Life.Die.NonviolentDeath_Victim')
Life_Die_Place = URIRef(NAMESPACE + 'Life.Die_Place')
Life_Die_Victim = URIRef(NAMESPACE + 'Life.Die_Victim')
Life_Injure_IllnessDegradationHungerThirst_Place = URIRef(NAMESPACE + 'Life.Injure.IllnessDegradationHungerThirst_Place')
Life_Injure_IllnessDegradationHungerThirst_Victim = URIRef(NAMESPACE + 'Life.Injure.IllnessDegradationHungerThirst_Victim')
Life_Injure_IllnessDegradationPhysical_Victim = URIRef(NAMESPACE + 'Life.Injure.IllnessDegradationPhysical_Victim')
Life_Injure_Injurer = URIRef(NAMESPACE + 'Life.Injure_Injurer')
Life_Injure_InjuryCausedByViolentEvents_Injurer = URIRef(NAMESPACE + 'Life.Injure.InjuryCausedByViolentEvents_Injurer')
Life_Injure_InjuryCausedByViolentEvents_Instrument = URIRef(NAMESPACE + 'Life.Injure.InjuryCausedByViolentEvents_Instrument')
Life_Injure_InjuryCausedByViolentEvents_Place = URIRef(NAMESPACE + 'Life.Injure.InjuryCausedByViolentEvents_Place')
Life_Injure_InjuryCausedByViolentEvents_Victim = URIRef(NAMESPACE + 'Life.Injure.InjuryCausedByViolentEvents_Victim')
Life_Injure_Place = URIRef(NAMESPACE + 'Life.Injure_Place')
Life_Injure_Victim = URIRef(NAMESPACE + 'Life.Injure_Victim')
Manufacture_Artifact_Artifact = URIRef(NAMESPACE + 'Manufacture.Artifact_Artifact')
Manufacture_Artifact_Build_Artifact = URIRef(NAMESPACE + 'Manufacture.Artifact.Build_Artifact')
Manufacture_Artifact_Build_Instrument = URIRef(NAMESPACE + 'Manufacture.Artifact.Build_Instrument')
Manufacture_Artifact_Build_Manufacturer = URIRef(NAMESPACE + 'Manufacture.Artifact.Build_Manufacturer')
Manufacture_Artifact_Build_Place = URIRef(NAMESPACE + 'Manufacture.Artifact.Build_Place')
Manufacture_Artifact_CreateIntellectualProperty_Artifact = URIRef(NAMESPACE + 'Manufacture.Artifact.CreateIntellectualProperty_Artifact')
Manufacture_Artifact_CreateIntellectualProperty_Instrument = URIRef(NAMESPACE + 'Manufacture.Artifact.CreateIntellectualProperty_Instrument')
Manufacture_Artifact_CreateIntellectualProperty_Manufacturer = URIRef(NAMESPACE + 'Manufacture.Artifact.CreateIntellectualProperty_Manufacturer')
Manufacture_Artifact_CreateIntellectualProperty_Place = URIRef(NAMESPACE + 'Manufacture.Artifact.CreateIntellectualProperty_Place')
Manufacture_Artifact_CreateManufacture_Artifact = URIRef(NAMESPACE + 'Manufacture.Artifact.CreateManufacture_Artifact')
Manufacture_Artifact_CreateManufacture_Instrument = URIRef(NAMESPACE + 'Manufacture.Artifact.CreateManufacture_Instrument')
Manufacture_Artifact_CreateManufacture_Manufacturer = URIRef(NAMESPACE + 'Manufacture.Artifact.CreateManufacture_Manufacturer')
Manufacture_Artifact_CreateManufacture_Place = URIRef(NAMESPACE + 'Manufacture.Artifact.CreateManufacture_Place')
Manufacture_Artifact_Instrument = URIRef(NAMESPACE + 'Manufacture.Artifact_Instrument')
Manufacture_Artifact_Manufacturer = URIRef(NAMESPACE + 'Manufacture.Artifact_Manufacturer')
Manufacture_Artifact_Place = URIRef(NAMESPACE + 'Manufacture.Artifact_Place')
Measurement_Size_Count_EntityOrFiller = URIRef(NAMESPACE + 'Measurement.Size.Count_EntityOrFiller')
Measurement_Size_Count_Measurement = URIRef(NAMESPACE + 'Measurement.Size.Count_Measurement')
Measurement_Size_EntityOrFiller = URIRef(NAMESPACE + 'Measurement.Size_EntityOrFiller')
Measurement_Size_HeightLengthWidth_EntityOrFiller = URIRef(NAMESPACE + 'Measurement.Size.HeightLengthWidth_EntityOrFiller')
Measurement_Size_HeightLengthWidth_Measurement = URIRef(NAMESPACE + 'Measurement.Size.HeightLengthWidth_Measurement')
Measurement_Size_Measurement = URIRef(NAMESPACE + 'Measurement.Size_Measurement')
Measurement_Size_Percentage_EntityOrFiller = URIRef(NAMESPACE + 'Measurement.Size.Percentage_EntityOrFiller')
Measurement_Size_Percentage_Measurement = URIRef(NAMESPACE + 'Measurement.Size.Percentage_Measurement')
Measurement_Size_Weight_EntityOrFiller = URIRef(NAMESPACE + 'Measurement.Size.Weight_EntityOrFiller')
Measurement_Size_Weight_Measurement = URIRef(NAMESPACE + 'Measurement.Size.Weight_Measurement')
Movement_TransportArtifact_Artifact = URIRef(NAMESPACE + 'Movement.TransportArtifact_Artifact')
Movement_TransportArtifact_BringCarryUnload_Artifact = URIRef(NAMESPACE + 'Movement.TransportArtifact.BringCarryUnload_Artifact')
Movement_TransportArtifact_BringCarryUnload_Destination = URIRef(NAMESPACE + 'Movement.TransportArtifact.BringCarryUnload_Destination')
Movement_TransportArtifact_BringCarryUnload_Origin = URIRef(NAMESPACE + 'Movement.TransportArtifact.BringCarryUnload_Origin')
Movement_TransportArtifact_BringCarryUnload_Transporter = URIRef(NAMESPACE + 'Movement.TransportArtifact.BringCarryUnload_Transporter')
Movement_TransportArtifact_BringCarryUnload_Vehicle = URIRef(NAMESPACE + 'Movement.TransportArtifact.BringCarryUnload_Vehicle')
Movement_TransportArtifact_Destination = URIRef(NAMESPACE + 'Movement.TransportArtifact_Destination')
Movement_TransportArtifact_DisperseSeparate_Artifact = URIRef(NAMESPACE + 'Movement.TransportArtifact.DisperseSeparate_Artifact')
Movement_TransportArtifact_DisperseSeparate_Destination = URIRef(NAMESPACE + 'Movement.TransportArtifact.DisperseSeparate_Destination')
Movement_TransportArtifact_DisperseSeparate_Origin = URIRef(NAMESPACE + 'Movement.TransportArtifact.DisperseSeparate_Origin')
Movement_TransportArtifact_DisperseSeparate_Transporter = URIRef(NAMESPACE + 'Movement.TransportArtifact.DisperseSeparate_Transporter')
Movement_TransportArtifact_DisperseSeparate_Vehicle = URIRef(NAMESPACE + 'Movement.TransportArtifact.DisperseSeparate_Vehicle')
Movement_TransportArtifact_Fall_Artifact = URIRef(NAMESPACE + 'Movement.TransportArtifact.Fall_Artifact')
Movement_TransportArtifact_Fall_Destination = URIRef(NAMESPACE + 'Movement.TransportArtifact.Fall_Destination')
Movement_TransportArtifact_Fall_Origin = URIRef(NAMESPACE + 'Movement.TransportArtifact.Fall_Origin')
Movement_TransportArtifact_GrantEntry_Artifact = URIRef(NAMESPACE + 'Movement.TransportArtifact.GrantEntry_Artifact')
Movement_TransportArtifact_GrantEntry_Destination = URIRef(NAMESPACE + 'Movement.TransportArtifact.GrantEntry_Destination')
Movement_TransportArtifact_GrantEntry_Origin = URIRef(NAMESPACE + 'Movement.TransportArtifact.GrantEntry_Origin')
Movement_TransportArtifact_GrantEntry_Transporter = URIRef(NAMESPACE + 'Movement.TransportArtifact.GrantEntry_Transporter')
Movement_TransportArtifact_Hide_Artifact = URIRef(NAMESPACE + 'Movement.TransportArtifact.Hide_Artifact')
Movement_TransportArtifact_Hide_HidingPlace = URIRef(NAMESPACE + 'Movement.TransportArtifact.Hide_HidingPlace')
Movement_TransportArtifact_Hide_Origin = URIRef(NAMESPACE + 'Movement.TransportArtifact.Hide_Origin')
Movement_TransportArtifact_Hide_Transporter = URIRef(NAMESPACE + 'Movement.TransportArtifact.Hide_Transporter')
Movement_TransportArtifact_Hide_Vehicle = URIRef(NAMESPACE + 'Movement.TransportArtifact.Hide_Vehicle')
Movement_TransportArtifact_NonviolentThrowLaunch_Artifact = URIRef(NAMESPACE + 'Movement.TransportArtifact.NonviolentThrowLaunch_Artifact')
Movement_TransportArtifact_NonviolentThrowLaunch_Destination = URIRef(NAMESPACE + 'Movement.TransportArtifact.NonviolentThrowLaunch_Destination')
Movement_TransportArtifact_NonviolentThrowLaunch_Origin = URIRef(NAMESPACE + 'Movement.TransportArtifact.NonviolentThrowLaunch_Origin')
Movement_TransportArtifact_NonviolentThrowLaunch_Transporter = URIRef(NAMESPACE + 'Movement.TransportArtifact.NonviolentThrowLaunch_Transporter')
Movement_TransportArtifact_NonviolentThrowLaunch_Vehicle = URIRef(NAMESPACE + 'Movement.TransportArtifact.NonviolentThrowLaunch_Vehicle')
Movement_TransportArtifact_Origin = URIRef(NAMESPACE + 'Movement.TransportArtifact_Origin')
Movement_TransportArtifact_PreventEntry_Artifact = URIRef(NAMESPACE + 'Movement.TransportArtifact.PreventEntry_Artifact')
Movement_TransportArtifact_PreventEntry_Destination = URIRef(NAMESPACE + 'Movement.TransportArtifact.PreventEntry_Destination')
Movement_TransportArtifact_PreventEntry_Origin = URIRef(NAMESPACE + 'Movement.TransportArtifact.PreventEntry_Origin')
Movement_TransportArtifact_PreventEntry_Preventer = URIRef(NAMESPACE + 'Movement.TransportArtifact.PreventEntry_Preventer')
Movement_TransportArtifact_PreventEntry_Transporter = URIRef(NAMESPACE + 'Movement.TransportArtifact.PreventEntry_Transporter')
Movement_TransportArtifact_PreventExit_Artifact = URIRef(NAMESPACE + 'Movement.TransportArtifact.PreventExit_Artifact')
Movement_TransportArtifact_PreventExit_Destination = URIRef(NAMESPACE + 'Movement.TransportArtifact.PreventExit_Destination')
Movement_TransportArtifact_PreventExit_Origin = URIRef(NAMESPACE + 'Movement.TransportArtifact.PreventExit_Origin')
Movement_TransportArtifact_PreventExit_Preventer = URIRef(NAMESPACE + 'Movement.TransportArtifact.PreventExit_Preventer')
Movement_TransportArtifact_PreventExit_Transporter = URIRef(NAMESPACE + 'Movement.TransportArtifact.PreventExit_Transporter')
Movement_TransportArtifact_ReceiveImport_Artifact = URIRef(NAMESPACE + 'Movement.TransportArtifact.ReceiveImport_Artifact')
Movement_TransportArtifact_ReceiveImport_Destination = URIRef(NAMESPACE + 'Movement.TransportArtifact.ReceiveImport_Destination')
Movement_TransportArtifact_ReceiveImport_Origin = URIRef(NAMESPACE + 'Movement.TransportArtifact.ReceiveImport_Origin')
Movement_TransportArtifact_ReceiveImport_Transporter = URIRef(NAMESPACE + 'Movement.TransportArtifact.ReceiveImport_Transporter')
Movement_TransportArtifact_ReceiveImport_Vehicle = URIRef(NAMESPACE + 'Movement.TransportArtifact.ReceiveImport_Vehicle')
Movement_TransportArtifact_SendSupplyExport_Artifact = URIRef(NAMESPACE + 'Movement.TransportArtifact.SendSupplyExport_Artifact')
Movement_TransportArtifact_SendSupplyExport_Destination = URIRef(NAMESPACE + 'Movement.TransportArtifact.SendSupplyExport_Destination')
Movement_TransportArtifact_SendSupplyExport_Origin = URIRef(NAMESPACE + 'Movement.TransportArtifact.SendSupplyExport_Origin')
Movement_TransportArtifact_SendSupplyExport_Transporter = URIRef(NAMESPACE + 'Movement.TransportArtifact.SendSupplyExport_Transporter')
Movement_TransportArtifact_SendSupplyExport_Vehicle = URIRef(NAMESPACE + 'Movement.TransportArtifact.SendSupplyExport_Vehicle')
Movement_TransportArtifact_SmuggleExtract_Artifact = URIRef(NAMESPACE + 'Movement.TransportArtifact.SmuggleExtract_Artifact')
Movement_TransportArtifact_SmuggleExtract_Destination = URIRef(NAMESPACE + 'Movement.TransportArtifact.SmuggleExtract_Destination')
Movement_TransportArtifact_SmuggleExtract_Origin = URIRef(NAMESPACE + 'Movement.TransportArtifact.SmuggleExtract_Origin')
Movement_TransportArtifact_SmuggleExtract_Transporter = URIRef(NAMESPACE + 'Movement.TransportArtifact.SmuggleExtract_Transporter')
Movement_TransportArtifact_SmuggleExtract_Vehicle = URIRef(NAMESPACE + 'Movement.TransportArtifact.SmuggleExtract_Vehicle')
Movement_TransportArtifact_Transporter = URIRef(NAMESPACE + 'Movement.TransportArtifact_Transporter')
Movement_TransportArtifact_Vehicle = URIRef(NAMESPACE + 'Movement.TransportArtifact_Vehicle')
Movement_TransportPerson_BringCarryUnload_Destination = URIRef(NAMESPACE + 'Movement.TransportPerson.BringCarryUnload_Destination')
Movement_TransportPerson_BringCarryUnload_Origin = URIRef(NAMESPACE + 'Movement.TransportPerson.BringCarryUnload_Origin')
Movement_TransportPerson_BringCarryUnload_Passenger = URIRef(NAMESPACE + 'Movement.TransportPerson.BringCarryUnload_Passenger')
Movement_TransportPerson_BringCarryUnload_Transporter = URIRef(NAMESPACE + 'Movement.TransportPerson.BringCarryUnload_Transporter')
Movement_TransportPerson_BringCarryUnload_Vehicle = URIRef(NAMESPACE + 'Movement.TransportPerson.BringCarryUnload_Vehicle')
Movement_TransportPerson_Destination = URIRef(NAMESPACE + 'Movement.TransportPerson_Destination')
Movement_TransportPerson_DisperseSeparate_Destination = URIRef(NAMESPACE + 'Movement.TransportPerson.DisperseSeparate_Destination')
Movement_TransportPerson_DisperseSeparate_Origin = URIRef(NAMESPACE + 'Movement.TransportPerson.DisperseSeparate_Origin')
Movement_TransportPerson_DisperseSeparate_Passenger = URIRef(NAMESPACE + 'Movement.TransportPerson.DisperseSeparate_Passenger')
Movement_TransportPerson_DisperseSeparate_Transporter = URIRef(NAMESPACE + 'Movement.TransportPerson.DisperseSeparate_Transporter')
Movement_TransportPerson_DisperseSeparate_Vehicle = URIRef(NAMESPACE + 'Movement.TransportPerson.DisperseSeparate_Vehicle')
Movement_TransportPerson_EvacuationRescue_Destination = URIRef(NAMESPACE + 'Movement.TransportPerson.EvacuationRescue_Destination')
Movement_TransportPerson_EvacuationRescue_Origin = URIRef(NAMESPACE + 'Movement.TransportPerson.EvacuationRescue_Origin')
Movement_TransportPerson_EvacuationRescue_Passenger = URIRef(NAMESPACE + 'Movement.TransportPerson.EvacuationRescue_Passenger')
Movement_TransportPerson_EvacuationRescue_Transporter = URIRef(NAMESPACE + 'Movement.TransportPerson.EvacuationRescue_Transporter')
Movement_TransportPerson_EvacuationRescue_Vehicle = URIRef(NAMESPACE + 'Movement.TransportPerson.EvacuationRescue_Vehicle')
Movement_TransportPerson_Fall_Destination = URIRef(NAMESPACE + 'Movement.TransportPerson.Fall_Destination')
Movement_TransportPerson_Fall_Origin = URIRef(NAMESPACE + 'Movement.TransportPerson.Fall_Origin')
Movement_TransportPerson_Fall_Passenger = URIRef(NAMESPACE + 'Movement.TransportPerson.Fall_Passenger')
Movement_TransportPerson_GrantEntryAsylum_Destination = URIRef(NAMESPACE + 'Movement.TransportPerson.GrantEntryAsylum_Destination')
Movement_TransportPerson_GrantEntryAsylum_Granter = URIRef(NAMESPACE + 'Movement.TransportPerson.GrantEntryAsylum_Granter')
Movement_TransportPerson_GrantEntryAsylum_Origin = URIRef(NAMESPACE + 'Movement.TransportPerson.GrantEntryAsylum_Origin')
Movement_TransportPerson_GrantEntryAsylum_Passenger = URIRef(NAMESPACE + 'Movement.TransportPerson.GrantEntryAsylum_Passenger')
Movement_TransportPerson_GrantEntryAsylum_Transporter = URIRef(NAMESPACE + 'Movement.TransportPerson.GrantEntryAsylum_Transporter')
Movement_TransportPerson_Hide_HidingPlace = URIRef(NAMESPACE + 'Movement.TransportPerson.Hide_HidingPlace')
Movement_TransportPerson_Hide_Origin = URIRef(NAMESPACE + 'Movement.TransportPerson.Hide_Origin')
Movement_TransportPerson_Hide_Passenger = URIRef(NAMESPACE + 'Movement.TransportPerson.Hide_Passenger')
Movement_TransportPerson_Hide_Transporter = URIRef(NAMESPACE + 'Movement.TransportPerson.Hide_Transporter')
Movement_TransportPerson_Hide_Vehicle = URIRef(NAMESPACE + 'Movement.TransportPerson.Hide_Vehicle')
Movement_TransportPerson_Origin = URIRef(NAMESPACE + 'Movement.TransportPerson_Origin')
Movement_TransportPerson_Passenger = URIRef(NAMESPACE + 'Movement.TransportPerson_Passenger')
Movement_TransportPerson_PreventEntry_Destination = URIRef(NAMESPACE + 'Movement.TransportPerson.PreventEntry_Destination')
Movement_TransportPerson_PreventEntry_Origin = URIRef(NAMESPACE + 'Movement.TransportPerson.PreventEntry_Origin')
Movement_TransportPerson_PreventEntry_Passenger = URIRef(NAMESPACE + 'Movement.TransportPerson.PreventEntry_Passenger')
Movement_TransportPerson_PreventEntry_Preventer = URIRef(NAMESPACE + 'Movement.TransportPerson.PreventEntry_Preventer')
Movement_TransportPerson_PreventEntry_Transporter = URIRef(NAMESPACE + 'Movement.TransportPerson.PreventEntry_Transporter')
Movement_TransportPerson_PreventExit_Destination = URIRef(NAMESPACE + 'Movement.TransportPerson.PreventExit_Destination')
Movement_TransportPerson_PreventExit_Origin = URIRef(NAMESPACE + 'Movement.TransportPerson.PreventExit_Origin')
Movement_TransportPerson_PreventExit_Passenger = URIRef(NAMESPACE + 'Movement.TransportPerson.PreventExit_Passenger')
Movement_TransportPerson_PreventExit_Preventer = URIRef(NAMESPACE + 'Movement.TransportPerson.PreventExit_Preventer')
Movement_TransportPerson_PreventExit_Transporter = URIRef(NAMESPACE + 'Movement.TransportPerson.PreventExit_Transporter')
Movement_TransportPerson_SelfMotion_Destination = URIRef(NAMESPACE + 'Movement.TransportPerson.SelfMotion_Destination')
Movement_TransportPerson_SelfMotion_Origin = URIRef(NAMESPACE + 'Movement.TransportPerson.SelfMotion_Origin')
Movement_TransportPerson_SelfMotion_Transporter = URIRef(NAMESPACE + 'Movement.TransportPerson.SelfMotion_Transporter')
Movement_TransportPerson_SelfMotion_Vehicle = URIRef(NAMESPACE + 'Movement.TransportPerson.SelfMotion_Vehicle')
Movement_TransportPerson_SmuggleExtract_Destination = URIRef(NAMESPACE + 'Movement.TransportPerson.SmuggleExtract_Destination')
Movement_TransportPerson_SmuggleExtract_Origin = URIRef(NAMESPACE + 'Movement.TransportPerson.SmuggleExtract_Origin')
Movement_TransportPerson_SmuggleExtract_Passenger = URIRef(NAMESPACE + 'Movement.TransportPerson.SmuggleExtract_Passenger')
Movement_TransportPerson_SmuggleExtract_Transporter = URIRef(NAMESPACE + 'Movement.TransportPerson.SmuggleExtract_Transporter')
Movement_TransportPerson_SmuggleExtract_Vehicle = URIRef(NAMESPACE + 'Movement.TransportPerson.SmuggleExtract_Vehicle')
Movement_TransportPerson_Transporter = URIRef(NAMESPACE + 'Movement.TransportPerson_Transporter')
Movement_TransportPerson_Vehicle = URIRef(NAMESPACE + 'Movement.TransportPerson_Vehicle')
OrganizationAffiliation_EmploymentMembership_EmployeeMember = URIRef(NAMESPACE + 'OrganizationAffiliation.EmploymentMembership_EmployeeMember')
OrganizationAffiliation_EmploymentMembership_Employment_Employee = URIRef(NAMESPACE + 'OrganizationAffiliation.EmploymentMembership.Employment_Employee')
OrganizationAffiliation_EmploymentMembership_Employment_PlaceOfEmployment = URIRef(NAMESPACE + 'OrganizationAffiliation.EmploymentMembership.Employment_PlaceOfEmployment')
OrganizationAffiliation_EmploymentMembership_Membership_Member = URIRef(NAMESPACE + 'OrganizationAffiliation.EmploymentMembership.Membership_Member')
OrganizationAffiliation_EmploymentMembership_Membership_PlaceOfMembership = URIRef(NAMESPACE + 'OrganizationAffiliation.EmploymentMembership.Membership_PlaceOfMembership')
OrganizationAffiliation_EmploymentMembership_PlaceOfEmploymentMembership = URIRef(NAMESPACE + 'OrganizationAffiliation.EmploymentMembership_PlaceOfEmploymentMembership')
OrganizationAffiliation_Founder_Founder_Founder = URIRef(NAMESPACE + 'OrganizationAffiliation.Founder.Founder_Founder')
OrganizationAffiliation_Founder_Founder_Organization = URIRef(NAMESPACE + 'OrganizationAffiliation.Founder.Founder_Organization')
OrganizationAffiliation_Leadership_Government_GovernmentBodyOrGPE = URIRef(NAMESPACE + 'OrganizationAffiliation.Leadership.Government_GovernmentBodyOrGPE')
OrganizationAffiliation_Leadership_Government_Leader = URIRef(NAMESPACE + 'OrganizationAffiliation.Leadership.Government_Leader')
OrganizationAffiliation_Leadership_HeadOfState_Country = URIRef(NAMESPACE + 'OrganizationAffiliation.Leadership.HeadOfState_Country')
OrganizationAffiliation_Leadership_HeadOfState_Leader = URIRef(NAMESPACE + 'OrganizationAffiliation.Leadership.HeadOfState_Leader')
OrganizationAffiliation_Leadership_Leader = URIRef(NAMESPACE + 'OrganizationAffiliation.Leadership_Leader')
OrganizationAffiliation_Leadership_MilitaryPolice_Leader = URIRef(NAMESPACE + 'OrganizationAffiliation.Leadership.MilitaryPolice_Leader')
OrganizationAffiliation_Leadership_MilitaryPolice_MilitaryPoliceORG = URIRef(NAMESPACE + 'OrganizationAffiliation.Leadership.MilitaryPolice_MilitaryPoliceORG')
OrganizationAffiliation_Leadership_Organization = URIRef(NAMESPACE + 'OrganizationAffiliation.Leadership_Organization')
PartWhole_Subsidiary_NationalityCitizen_Parent = URIRef(NAMESPACE + 'PartWhole.Subsidiary.NationalityCitizen_Parent')
PartWhole_Subsidiary_NationalityCitizen_Subsidiary = URIRef(NAMESPACE + 'PartWhole.Subsidiary.NationalityCitizen_Subsidiary')
PartWhole_Subsidiary_OrganizationSubsidiary_Parent = URIRef(NAMESPACE + 'PartWhole.Subsidiary.OrganizationSubsidiary_Parent')
PartWhole_Subsidiary_OrganizationSubsidiary_Subsidiary = URIRef(NAMESPACE + 'PartWhole.Subsidiary.OrganizationSubsidiary_Subsidiary')
PartWhole_Subsidiary_Parent = URIRef(NAMESPACE + 'PartWhole.Subsidiary_Parent')
PartWhole_Subsidiary_Subsidiary = URIRef(NAMESPACE + 'PartWhole.Subsidiary_Subsidiary')
PersonalSocial_Role_Person = URIRef(NAMESPACE + 'PersonalSocial.Role_Person')
PersonalSocial_Role_ProfessionalRole_JobRole = URIRef(NAMESPACE + 'PersonalSocial.Role.ProfessionalRole_JobRole')
PersonalSocial_Role_ProfessionalRole_Person = URIRef(NAMESPACE + 'PersonalSocial.Role.ProfessionalRole_Person')
PersonalSocial_Role_Role = URIRef(NAMESPACE + 'PersonalSocial.Role_Role')
PersonalSocial_Role_TitleFormOfAddress_Person = URIRef(NAMESPACE + 'PersonalSocial.Role.TitleFormOfAddress_Person')
PersonalSocial_Role_TitleFormOfAddress_Title = URIRef(NAMESPACE + 'PersonalSocial.Role.TitleFormOfAddress_Title')
PersonalSocial_Unspecified_Person = URIRef(NAMESPACE + 'PersonalSocial.Unspecified_Person')
PersonalSocial_Unspecified_Political_Person = URIRef(NAMESPACE + 'PersonalSocial.Unspecified.Political_Person')
Personnel_Elect_Candidate = URIRef(NAMESPACE + 'Personnel.Elect_Candidate')
Personnel_Elect_Place = URIRef(NAMESPACE + 'Personnel.Elect_Place')
Personnel_Elect_Voter = URIRef(NAMESPACE + 'Personnel.Elect_Voter')
Personnel_Elect_WinElection_Candidate = URIRef(NAMESPACE + 'Personnel.Elect.WinElection_Candidate')
Personnel_Elect_WinElection_Place = URIRef(NAMESPACE + 'Personnel.Elect.WinElection_Place')
Personnel_Elect_WinElection_Voter = URIRef(NAMESPACE + 'Personnel.Elect.WinElection_Voter')
Personnel_EndPosition_Employee = URIRef(NAMESPACE + 'Personnel.EndPosition_Employee')
Personnel_EndPosition_FiringLayoff_Employee = URIRef(NAMESPACE + 'Personnel.EndPosition.FiringLayoff_Employee')
Personnel_EndPosition_FiringLayoff_Place = URIRef(NAMESPACE + 'Personnel.EndPosition.FiringLayoff_Place')
Personnel_EndPosition_FiringLayoff_PlaceOfEmployment = URIRef(NAMESPACE + 'Personnel.EndPosition.FiringLayoff_PlaceOfEmployment')
Personnel_EndPosition_Place = URIRef(NAMESPACE + 'Personnel.EndPosition_Place')
Personnel_EndPosition_PlaceOfEmployment = URIRef(NAMESPACE + 'Personnel.EndPosition_PlaceOfEmployment')
Personnel_EndPosition_QuitRetire_Employee = URIRef(NAMESPACE + 'Personnel.EndPosition.QuitRetire_Employee')
Personnel_EndPosition_QuitRetire_Place = URIRef(NAMESPACE + 'Personnel.EndPosition.QuitRetire_Place')
Personnel_EndPosition_QuitRetire_PlaceOfEmployment = URIRef(NAMESPACE + 'Personnel.EndPosition.QuitRetire_PlaceOfEmployment')
Personnel_StartPosition_Employee = URIRef(NAMESPACE + 'Personnel.StartPosition_Employee')
Personnel_StartPosition_Hiring_Employee = URIRef(NAMESPACE + 'Personnel.StartPosition.Hiring_Employee')
Personnel_StartPosition_Hiring_Place = URIRef(NAMESPACE + 'Personnel.StartPosition.Hiring_Place')
Personnel_StartPosition_Hiring_PlaceOfEmployment = URIRef(NAMESPACE + 'Personnel.StartPosition.Hiring_PlaceOfEmployment')
Personnel_StartPosition_Place = URIRef(NAMESPACE + 'Personnel.StartPosition_Place')
Personnel_StartPosition_PlaceOfEmployment = URIRef(NAMESPACE + 'Personnel.StartPosition_PlaceOfEmployment')
Physical_LocatedNear_EntityOrFiller = URIRef(NAMESPACE + 'Physical.LocatedNear_EntityOrFiller')
Physical_LocatedNear_Place = URIRef(NAMESPACE + 'Physical.LocatedNear_Place')
Physical_LocatedNear_Surround_EntityOrFiller = URIRef(NAMESPACE + 'Physical.LocatedNear.Surround_EntityOrFiller')
Physical_LocatedNear_Surround_Place = URIRef(NAMESPACE + 'Physical.LocatedNear.Surround_Place')
Physical_OrganizationHeadquarters_OrganizationHeadquarters_Organization = URIRef(NAMESPACE + 'Physical.OrganizationHeadquarters.OrganizationHeadquarters_Organization')
Physical_OrganizationHeadquarters_OrganizationHeadquarters_Place = URIRef(NAMESPACE + 'Physical.OrganizationHeadquarters.OrganizationHeadquarters_Place')
Physical_Resident_Resident_Place = URIRef(NAMESPACE + 'Physical.Resident.Resident_Place')
Physical_Resident_Resident_Resident = URIRef(NAMESPACE + 'Physical.Resident.Resident_Resident')
ResponsibilityBlame_AssignBlame_AssignBlame_EntityResponsible = URIRef(NAMESPACE + 'ResponsibilityBlame.AssignBlame.AssignBlame_EntityResponsible')
ResponsibilityBlame_AssignBlame_AssignBlame_Event = URIRef(NAMESPACE + 'ResponsibilityBlame.AssignBlame.AssignBlame_Event')
ResponsibilityBlame_ClaimResponsibility_ClaimResponsibility_EntityResponsible = URIRef(NAMESPACE + 'ResponsibilityBlame.ClaimResponsibility.ClaimResponsibility_EntityResponsible')
ResponsibilityBlame_ClaimResponsibility_ClaimResponsibility_Event = URIRef(NAMESPACE + 'ResponsibilityBlame.ClaimResponsibility.ClaimResponsibility_Event')
Transaction_Transaction_Beneficiary = URIRef(NAMESPACE + 'Transaction.Transaction_Beneficiary')
Transaction_Transaction_EmbargoSanction_ArtifactMoney = URIRef(NAMESPACE + 'Transaction.Transaction.EmbargoSanction_ArtifactMoney')
Transaction_Transaction_EmbargoSanction_Giver = URIRef(NAMESPACE + 'Transaction.Transaction.EmbargoSanction_Giver')
Transaction_Transaction_EmbargoSanction_Place = URIRef(NAMESPACE + 'Transaction.Transaction.EmbargoSanction_Place')
Transaction_Transaction_EmbargoSanction_Preventer = URIRef(NAMESPACE + 'Transaction.Transaction.EmbargoSanction_Preventer')
Transaction_Transaction_EmbargoSanction_Recipient = URIRef(NAMESPACE + 'Transaction.Transaction.EmbargoSanction_Recipient')
Transaction_Transaction_GiftGrantProvideAid_Beneficiary = URIRef(NAMESPACE + 'Transaction.Transaction.GiftGrantProvideAid_Beneficiary')
Transaction_Transaction_GiftGrantProvideAid_Giver = URIRef(NAMESPACE + 'Transaction.Transaction.GiftGrantProvideAid_Giver')
Transaction_Transaction_GiftGrantProvideAid_Place = URIRef(NAMESPACE + 'Transaction.Transaction.GiftGrantProvideAid_Place')
Transaction_Transaction_GiftGrantProvideAid_Recipient = URIRef(NAMESPACE + 'Transaction.Transaction.GiftGrantProvideAid_Recipient')
Transaction_Transaction_Participant = URIRef(NAMESPACE + 'Transaction.Transaction_Participant')
Transaction_Transaction_Place = URIRef(NAMESPACE + 'Transaction.Transaction_Place')
Transaction_Transaction_TransferControl_Beneficiary = URIRef(NAMESPACE + 'Transaction.Transaction.TransferControl_Beneficiary')
Transaction_Transaction_TransferControl_Giver = URIRef(NAMESPACE + 'Transaction.Transaction.TransferControl_Giver')
Transaction_Transaction_TransferControl_Place = URIRef(NAMESPACE + 'Transaction.Transaction.TransferControl_Place')
Transaction_Transaction_TransferControl_Recipient = URIRef(NAMESPACE + 'Transaction.Transaction.TransferControl_Recipient')
Transaction_Transaction_TransferControl_TerritoryOrFacility = URIRef(NAMESPACE + 'Transaction.Transaction.TransferControl_TerritoryOrFacility')
Transaction_TransferMoney_Beneficiary = URIRef(NAMESPACE + 'Transaction.TransferMoney_Beneficiary')
Transaction_TransferMoney_BorrowLend_Beneficiary = URIRef(NAMESPACE + 'Transaction.TransferMoney.BorrowLend_Beneficiary')
Transaction_TransferMoney_BorrowLend_Giver = URIRef(NAMESPACE + 'Transaction.TransferMoney.BorrowLend_Giver')
Transaction_TransferMoney_BorrowLend_Money = URIRef(NAMESPACE + 'Transaction.TransferMoney.BorrowLend_Money')
Transaction_TransferMoney_BorrowLend_Place = URIRef(NAMESPACE + 'Transaction.TransferMoney.BorrowLend_Place')
Transaction_TransferMoney_BorrowLend_Recipient = URIRef(NAMESPACE + 'Transaction.TransferMoney.BorrowLend_Recipient')
Transaction_TransferMoney_EmbargoSanction_Giver = URIRef(NAMESPACE + 'Transaction.TransferMoney.EmbargoSanction_Giver')
Transaction_TransferMoney_EmbargoSanction_Money = URIRef(NAMESPACE + 'Transaction.TransferMoney.EmbargoSanction_Money')
Transaction_TransferMoney_EmbargoSanction_Place = URIRef(NAMESPACE + 'Transaction.TransferMoney.EmbargoSanction_Place')
Transaction_TransferMoney_EmbargoSanction_Preventer = URIRef(NAMESPACE + 'Transaction.TransferMoney.EmbargoSanction_Preventer')
Transaction_TransferMoney_EmbargoSanction_Recipient = URIRef(NAMESPACE + 'Transaction.TransferMoney.EmbargoSanction_Recipient')
Transaction_TransferMoney_GiftGrantProvideAid_Beneficiary = URIRef(NAMESPACE + 'Transaction.TransferMoney.GiftGrantProvideAid_Beneficiary')
Transaction_TransferMoney_GiftGrantProvideAid_Giver = URIRef(NAMESPACE + 'Transaction.TransferMoney.GiftGrantProvideAid_Giver')
Transaction_TransferMoney_GiftGrantProvideAid_Money = URIRef(NAMESPACE + 'Transaction.TransferMoney.GiftGrantProvideAid_Money')
Transaction_TransferMoney_GiftGrantProvideAid_Place = URIRef(NAMESPACE + 'Transaction.TransferMoney.GiftGrantProvideAid_Place')
Transaction_TransferMoney_GiftGrantProvideAid_Recipient = URIRef(NAMESPACE + 'Transaction.TransferMoney.GiftGrantProvideAid_Recipient')
Transaction_TransferMoney_Giver = URIRef(NAMESPACE + 'Transaction.TransferMoney_Giver')
Transaction_TransferMoney_Money = URIRef(NAMESPACE + 'Transaction.TransferMoney_Money')
Transaction_TransferMoney_PayForService_Beneficiary = URIRef(NAMESPACE + 'Transaction.TransferMoney.PayForService_Beneficiary')
Transaction_TransferMoney_PayForService_Giver = URIRef(NAMESPACE + 'Transaction.TransferMoney.PayForService_Giver')
Transaction_TransferMoney_PayForService_Money = URIRef(NAMESPACE + 'Transaction.TransferMoney.PayForService_Money')
Transaction_TransferMoney_PayForService_Place = URIRef(NAMESPACE + 'Transaction.TransferMoney.PayForService_Place')
Transaction_TransferMoney_PayForService_Recipient = URIRef(NAMESPACE + 'Transaction.TransferMoney.PayForService_Recipient')
Transaction_TransferMoney_Place = URIRef(NAMESPACE + 'Transaction.TransferMoney_Place')
Transaction_TransferMoney_Purchase_Beneficiary = URIRef(NAMESPACE + 'Transaction.TransferMoney.Purchase_Beneficiary')
Transaction_TransferMoney_Purchase_Giver = URIRef(NAMESPACE + 'Transaction.TransferMoney.Purchase_Giver')
Transaction_TransferMoney_Purchase_Money = URIRef(NAMESPACE + 'Transaction.TransferMoney.Purchase_Money')
Transaction_TransferMoney_Purchase_Place = URIRef(NAMESPACE + 'Transaction.TransferMoney.Purchase_Place')
Transaction_TransferMoney_Purchase_Recipient = URIRef(NAMESPACE + 'Transaction.TransferMoney.Purchase_Recipient')
Transaction_TransferMoney_Recipient = URIRef(NAMESPACE + 'Transaction.TransferMoney_Recipient')
Transaction_TransferOwnership_Artifact = URIRef(NAMESPACE + 'Transaction.TransferOwnership_Artifact')
Transaction_TransferOwnership_Beneficiary = URIRef(NAMESPACE + 'Transaction.TransferOwnership_Beneficiary')
Transaction_TransferOwnership_BorrowLend_Artifact = URIRef(NAMESPACE + 'Transaction.TransferOwnership.BorrowLend_Artifact')
Transaction_TransferOwnership_BorrowLend_Beneficiary = URIRef(NAMESPACE + 'Transaction.TransferOwnership.BorrowLend_Beneficiary')
Transaction_TransferOwnership_BorrowLend_Giver = URIRef(NAMESPACE + 'Transaction.TransferOwnership.BorrowLend_Giver')
Transaction_TransferOwnership_BorrowLend_Place = URIRef(NAMESPACE + 'Transaction.TransferOwnership.BorrowLend_Place')
Transaction_TransferOwnership_BorrowLend_Recipient = URIRef(NAMESPACE + 'Transaction.TransferOwnership.BorrowLend_Recipient')
Transaction_TransferOwnership_EmbargoSanction_Artifact = URIRef(NAMESPACE + 'Transaction.TransferOwnership.EmbargoSanction_Artifact')
Transaction_TransferOwnership_EmbargoSanction_Giver = URIRef(NAMESPACE + 'Transaction.TransferOwnership.EmbargoSanction_Giver')
Transaction_TransferOwnership_EmbargoSanction_Place = URIRef(NAMESPACE + 'Transaction.TransferOwnership.EmbargoSanction_Place')
Transaction_TransferOwnership_EmbargoSanction_Preventer = URIRef(NAMESPACE + 'Transaction.TransferOwnership.EmbargoSanction_Preventer')
Transaction_TransferOwnership_EmbargoSanction_Recipient = URIRef(NAMESPACE + 'Transaction.TransferOwnership.EmbargoSanction_Recipient')
Transaction_TransferOwnership_GiftGrantProvideAid_Artifact = URIRef(NAMESPACE + 'Transaction.TransferOwnership.GiftGrantProvideAid_Artifact')
Transaction_TransferOwnership_GiftGrantProvideAid_Beneficiary = URIRef(NAMESPACE + 'Transaction.TransferOwnership.GiftGrantProvideAid_Beneficiary')
Transaction_TransferOwnership_GiftGrantProvideAid_Giver = URIRef(NAMESPACE + 'Transaction.TransferOwnership.GiftGrantProvideAid_Giver')
Transaction_TransferOwnership_GiftGrantProvideAid_Place = URIRef(NAMESPACE + 'Transaction.TransferOwnership.GiftGrantProvideAid_Place')
Transaction_TransferOwnership_GiftGrantProvideAid_Recipient = URIRef(NAMESPACE + 'Transaction.TransferOwnership.GiftGrantProvideAid_Recipient')
Transaction_TransferOwnership_Giver = URIRef(NAMESPACE + 'Transaction.TransferOwnership_Giver')
Transaction_TransferOwnership_Place = URIRef(NAMESPACE + 'Transaction.TransferOwnership_Place')
Transaction_TransferOwnership_Purchase_Artifact = URIRef(NAMESPACE + 'Transaction.TransferOwnership.Purchase_Artifact')
Transaction_TransferOwnership_Purchase_Beneficiary = URIRef(NAMESPACE + 'Transaction.TransferOwnership.Purchase_Beneficiary')
Transaction_TransferOwnership_Purchase_Giver = URIRef(NAMESPACE + 'Transaction.TransferOwnership.Purchase_Giver')
Transaction_TransferOwnership_Purchase_Place = URIRef(NAMESPACE + 'Transaction.TransferOwnership.Purchase_Place')
Transaction_TransferOwnership_Purchase_Recipient = URIRef(NAMESPACE + 'Transaction.TransferOwnership.Purchase_Recipient')
Transaction_TransferOwnership_Recipient = URIRef(NAMESPACE + 'Transaction.TransferOwnership_Recipient')
